<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<!--
*
*	Date 	    Programmer		 Version		Description
*	~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*	07/30/2014	Sebastian Radau  	1.0.0		Created 
*	12/20/2016	Thomas Gertler  	1.1.0		webcomponents compatiblity 
*												
*	Copyright (c) G+H Systems GmbH, 2014
*	
*	This development kit is proprietary to G+H Systems GmbH.	
*	All rights reserved. For more information visit the website:
*   www.inchorus.de	
*							
*************************************************************************/-->

	<!-- Output Definition - Beginning -->
	<xsl:output method="html" encoding="<!--GADGET:ENCODING-->" />	
	<!-- Output Definition - End -->

	<!-- Language File Include - Beginning -->
	<xsl:include href="<!--GADGET:LANGUAGE-->/language_webcomponents.xsl" />
	<xsl:include href="<!--GADGET:LANGUAGE-->/language.xsl" />
	<!-- Language File Include - End -->
	
	<!-- Gadget Variables File Include - Beginning -->
	<xsl:include href="gadget_variables.xsl" />
	<!-- Gadget Variables File Include - End -->
	
	<xsl:template match="data">
		<xsl:variable name="thisid">configuration-modify</xsl:variable>
		<xsl:variable name="parentid">exchange</xsl:variable>
		
		<xsl:variable name="configurationmode" select="//data/parameters/parameter[@name='configurationmode']/text()"/>
		<xsl:variable name="contentcontainerid" select="//data/parameters/parameter[@name='contentcontainerid']"/>
		<xsl:variable name="contentvariationid" select="//data/parameters/parameter[@name='contentvariationid']/text()"/>
		<xsl:variable name="mode" select="//data/parameters/parameter[@name='mode']"/>
		<xsl:variable name="datatypes" select="//data/parameters/parameter[@name='datatypes']"/>
		<xsl:variable name="charttypes" select="//data/parameters/parameter[@name='charttypes']"/>
		
		<inchorus-form>
			<xsl:attribute name="id"><xsl:value-of select="$thisid"/>-form</xsl:attribute>
			<xsl:attribute name="submitprefix">inc-</xsl:attribute>
			<xsl:attribute name="hasresponsefile">true</xsl:attribute>
			<xsl:attribute name="alternativeresponsefile">contentcontainer-dashboard-edit-response</xsl:attribute>
			<xsl:attribute name="responsetargetid"><xsl:value-of select="$thisid"/>-form-response</xsl:attribute>
			<xsl:attribute name="alternativegadgetid">1</xsl:attribute>

			<xsl:choose>
				<xsl:when test="$configurationmode = 'edit'">
					<xsl:attribute name="command">setPortalContentvariationConfiguration</xsl:attribute>
				</xsl:when>
				<xsl:when test="$configurationmode = 'add'">
					<xsl:attribute name="command">addContentvariationToContentcontainer</xsl:attribute>				
				</xsl:when>
			</xsl:choose>

			<xsl:attribute name="parameters">[{"contentcontainerid":"<xsl:value-of select="$contentcontainerid" />"},{"contentvariationid":"<xsl:value-of select="$contentvariationid" />"},{"containerid":"g<xsl:value-of select="$contentvariationid" />"}]</xsl:attribute>
			
			<input type="hidden" id="gs-w" name="inc-attribute-gs-w">
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="$mode = 'small_numbers'">4</xsl:when>
						<xsl:when test="$mode = 'medium_numbers_charts'">8</xsl:when>
						<xsl:when test="$mode = 'big_all'">8</xsl:when>
						<xsl:otherwise>4</xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</input>
			<input type="hidden" id="gs-h" name="inc-attribute-gs-h">
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="$mode = 'small_numbers'">2</xsl:when>
						<xsl:when test="$mode = 'medium_numbers_charts'">4</xsl:when>
						<xsl:when test="$mode = 'big_all'">8</xsl:when>
						<xsl:otherwise>2</xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</input>
			<input type="hidden" id="datatypes" name="inc-parameter-datatypes">
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="$datatypes != ''"><xsl:value-of select="$datatypes" /></xsl:when>
						<xsl:when test="$mode = 'big_all'"></xsl:when>
						<xsl:otherwise>mailbox</xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</input>
			<input type="hidden" id="charttypes" name="inc-parameter-charttypes">
					<xsl:attribute name="value">
						<xsl:if test="$charttypes != ''"><xsl:value-of select="$charttypes" /></xsl:if>
					</xsl:attribute>
			</input>
			
			<inchorus-radio id="modus-select">
				<xsl:attribute name="id">modus-select</xsl:attribute>
			    <xsl:attribute name="name">inc-parameter-mode</xsl:attribute>
    			<xsl:attribute name="type">vertical</xsl:attribute>
    			<xsl:attribute name="preselect">
    				<xsl:choose>
    					<xsl:when test="$mode = 'small_numbers'">modus-select-small-numbers</xsl:when>
    					<xsl:when test="$mode = 'medium_numbers_charts'">modus-select-medium-numbers-charts</xsl:when>
    					<xsl:when test="$mode = 'big_all'">modus-select-big-all</xsl:when>
    					<xsl:otherwise>modus-select-small-numbers</xsl:otherwise>
    				</xsl:choose>
    			</xsl:attribute>
    			
				<div class="exchange-config-mode-radio-box">
					<div class="exchange-config-mode-radio-box-radiowrapper">
						<inchorus-radio-item>
		   					<xsl:attribute name="id">modus-select-small-numbers</xsl:attribute>
		   					<xsl:attribute name="name">modus-select-small-numbers</xsl:attribute>
		   					<xsl:attribute name="value">small_numbers</xsl:attribute>
		   					<xsl:attribute name="onclick">
								$("#gs-w").val("4"); 
								$("#gs-h").val("2");
								$("#datatypes").val($('#<xsl:value-of select="$parentid" />-small-numbers-datatype select').val());
								$("#charttypes").val('');				
		   					</xsl:attribute>
		   				    <xsl:if test="$mode='small_numbers'">
			   				    <xsl:attribute name="checked">
			   				    	checked
			   				    </xsl:attribute>
		   				    </xsl:if>
		  				</inchorus-radio-item>
					</div>
					<div class="exchange-config-mode-radio-box-radiowrapper-content">
						<div class="exchange-config-mode-radio-box-headline"><xsl:value-of select="$exchange_config_modus_small_numbers" /></div>
						<div class="exchange-config-mode-radio-box-text">
							<xsl:value-of select="$exchange_config_modus_small_numbers_description" />
						</div>
						<div class="exchange-config-mode-radio-box-options">
							<label class="exchange-config-mode-radio-box-label-data">
								<xsl:value-of select="$exchange_config_label_data" />&#160;
							</label>
							<inchorus-select>
								<xsl:attribute name="id"><xsl:value-of select="$parentid" />-small-numbers-datatype</xsl:attribute>
								<xsl:attribute name="name">modus-select-datatypes</xsl:attribute>
								<xsl:attribute name="hascontentfile">true</xsl:attribute>
								<xsl:attribute name="alternativecontentfile">select-datatypes</xsl:attribute>
								<xsl:attribute name="command">getDefaultData</xsl:attribute>
								<xsl:attribute name="active">true</xsl:attribute>
								<xsl:attribute name="preselect">
								<xsl:choose>
									<xsl:when test="$mode='small_numbers'"> 
										<xsl:value-of select="$datatypes" />
									</xsl:when>
									<xsl:otherwise>mailbox</xsl:otherwise>
								</xsl:choose>
								</xsl:attribute>
								<xsl:attribute name="onchange">
									$("#gs-w").val("4"); 
									$("#gs-h").val("2");
									inchorus.$('modus-select').setCheckeditemid('modus-select-small-numbers');
									var datatypes = $('#<xsl:value-of select="$parentid" />-small-numbers-datatype select').val();
									$('#datatypes').val(datatypes);
									$("#charttypes").val('');
								</xsl:attribute>
							</inchorus-select>
						</div>
					</div>
					<div class="activedirector-config-mode-radio-box-image-wrapper">
						<div class="exchange-config-mode-radio-box-image">
						</div>
					</div>
				</div>
				
				<div class="exchange-config-mode-radio-box">
					<div class="exchange-config-mode-radio-box-radiowrapper">
						<inchorus-radio-item>
		   					<xsl:attribute name="id">modus-select-medium-numbers-charts</xsl:attribute>
		   					<xsl:attribute name="name">modus-select-medium-numbers-charts</xsl:attribute>
		   					<xsl:attribute name="value">medium_numbers_charts</xsl:attribute>
		   					<xsl:attribute name="onclick">
								$("#gs-w").val("8"); 
								$("#gs-h").val("4"); 	
								$("#datatypes").val($('#<xsl:value-of select="$parentid" />-medium-numbers-charts-datatype select').val());
								$('#charttypes').val($('#configuration-modify-medium-numbers-charts-charttypes-multiselect-selectbox-head').val());	
		   					</xsl:attribute>
		   					<xsl:if test="$mode='medium_numbers_charts'">
			   				    <xsl:attribute name="checked">
			   				    	checked
			   				    </xsl:attribute>
		   				    </xsl:if>
		  				</inchorus-radio-item>
					</div>
					
					<div>
						<div class="exchange-config-mode-radio-box-radiowrapper-content">
							<div class="exchange-config-mode-radio-box-headline"><xsl:value-of select="$exchange_config_modus_medium_numbers_charts" /></div>
							<div class="exchange-config-mode-radio-box-text">
								<xsl:value-of select="$exchange_config_modus_medium_numbers_description" />
							</div>

							<div class="exchange-config-mode-radio-box-options">
									<label class="exchange-config-mode-radio-box-label-data">
										<xsl:value-of select="$exchange_config_label_data" />&#160;
									</label>
									<inchorus-select>
										<xsl:attribute name="id"><xsl:value-of select="$parentid" />-medium-numbers-charts-datatype</xsl:attribute>
										<xsl:attribute name="name">modus-select-datatypes</xsl:attribute>
										<xsl:attribute name="hascontentfile">true</xsl:attribute>
										<xsl:attribute name="alternativecontentfile">select-datatypes</xsl:attribute>
										<xsl:attribute name="command">getDefaultData</xsl:attribute>
										<xsl:attribute name="active">true</xsl:attribute>
										<xsl:attribute name="preselect">
											<xsl:choose>
												<xsl:when test="$mode='medium_numbers_charts'"> 
													<xsl:value-of select="$datatypes" />
												</xsl:when>
											<xsl:otherwise>mailbox</xsl:otherwise>
											</xsl:choose>
										</xsl:attribute>
										<xsl:attribute name="onchange">
											$("#gs-w").val("8"); 
											$("#gs-h").val("4");
											inchorus.$('modus-select').setCheckeditemid('modus-select-medium-numbers-charts');
											var datatypes = $('#<xsl:value-of select="$parentid" />-medium-numbers-charts-datatype select').val();
											$('#datatypes').val(datatypes);
											inchorus.$('<xsl:value-of select="$parentid" />-medium-numbers-charts-charttypes-multiselect-wrapper').setParameters(
												{
													datatypes: datatypes,
													preselect: ""
												}
											);
											inchorus.$('<xsl:value-of select="$parentid" />-medium-numbers-charts-charttypes-multiselect-wrapper').load();
											setTimeout(function(){
												$('#charttypes').val($('#configuration-modify-medium-numbers-charts-charttypes-multiselect-selectbox-head').val());
											}, 300);
										</xsl:attribute>
									</inchorus-select>
								</div>
								<div class="exchange-config-mode-radio-box-options">
									<label class="exchange-config-mode-radio-box-label-charts">
										<xsl:value-of select="$exchange_config_label_charts" />
									</label>
									<inchorus-checkboxes>
										<xsl:attribute name="id"><xsl:value-of select="$parentid" />-medium-numbers-charts-charttypes-multiselect-wrapper</xsl:attribute>
										<xsl:attribute name="active">true</xsl:attribute>
										<xsl:attribute name="hascontentfile">true</xsl:attribute>
										<xsl:attribute name="alternativecontentfile"><xsl:value-of select="$thisid" />-multiselect-charttypes</xsl:attribute>
										<xsl:attribute name="command">getDefaultData</xsl:attribute>
										<xsl:attribute name="parameters">
											<xsl:choose>
												<xsl:when test="$mode='medium_numbers_charts'">[{"datatypes":"<xsl:value-of select="$datatypes"/>"},{"preselect":"<xsl:value-of select="$charttypes"/>"}]</xsl:when>
												<xsl:otherwise>[{"datatypes":"mailbox"},{"preselect":""}]</xsl:otherwise>
											</xsl:choose>
										</xsl:attribute>
									</inchorus-checkboxes>									
								</div>					
							</div>
							<div class="exchange-config-mode-radio-box-image-wrapper">
								<div class="exchange-dashboard-image-medium-numbers-charts-distributiongroup" style="margin:0px;">
								</div>
							</div>
						</div>
					</div>
				
				
					<div class="exchange-config-mode-radio-box" style="max-height:211px;">
						<div class="exchange-config-mode-radio-box-radiowrapper">
							<inchorus-radio-item>
			   					<xsl:attribute name="id">modus-select-big-all</xsl:attribute>
			   					<xsl:attribute name="name">modus-select-big-all</xsl:attribute>
			   					<xsl:attribute name="value">big_all</xsl:attribute>
			   					<xsl:attribute name="style">margin-top:1px;</xsl:attribute>
			   					<xsl:attribute name="onclick">
									$("#gs-w").val("8"); 
									$("#gs-h").val("8");
									$("#datatypes").val('');
									$("#charttypes").val('');		
			   					</xsl:attribute>
			   					<xsl:if test="$mode='big_all'">
				   				    <xsl:attribute name="checked">
				   				    	checked
				   				    </xsl:attribute>
			   				    </xsl:if>
			  				</inchorus-radio-item>
						</div>
						<div class="exchange-config-mode-radio-box-radiowrapper-content">
							<div class="exchange-config-mode-radio-box-headline"><xsl:value-of select="$exchange_config_modus_big_all" /></div>
							<div class="exchange-config-mode-radio-box-text">
								<xsl:value-of select="$exchange_config_modus_big_all_description" />
							</div>
						</div>
						<div class="exchange-config-mode-radio-box-image-wrapper">
							<div class="exchange-dashboard-image-big-all" style="margin:0px;">
							</div>
						</div>
					</div>
				</inchorus-radio>
			
			
			<div>					
				<xsl:attribute name="id"><xsl:value-of select="$thisid"/>-form-response</xsl:attribute>
			</div>
			
			<inchorus-button>
				<xsl:attribute name="id"><xsl:value-of select="$thisid"/>-button-save</xsl:attribute>				
				<xsl:attribute name="onclick">
					inchorus.$('<xsl:value-of select="$thisid"/>-form').submit();
					inchorus.$('<xsl:value-of select="$thisid"/>-button-save').deactivate();
					inchorus.$('<xsl:value-of select="$thisid"/>-button-terminate').deactivate();
				</xsl:attribute>
				<xsl:attribute name="type">icontext</xsl:attribute>
				<xsl:attribute name="icon">save</xsl:attribute>
				<xsl:attribute name="text"><xsl:value-of select="$inchorus_button_save" /></xsl:attribute>
				<xsl:attribute name="highlighting">low</xsl:attribute>
				<xsl:attribute name="active">true</xsl:attribute>
			</inchorus-button>
			
			<inchorus-button>
				<xsl:attribute name="id"><xsl:value-of select="$thisid"/>-button-terminate</xsl:attribute>					
				<xsl:attribute name="onclick">
					<xsl:choose>
						<xsl:when test="$configurationmode = 'add'">
						inchorus.$('contentcontainer-dashboard-edit-lightbox-add').deactivate();
						</xsl:when>
						<xsl:when test="$configurationmode = 'edit'">
							inchorus.$('<xsl:value-of select="$parentid"/>-edit-lightbox-config-<xsl:value-of select="$contentvariationid" />').deactivate();
						</xsl:when>
					</xsl:choose>
				</xsl:attribute>
				<xsl:attribute name="type">icontext</xsl:attribute>
				<xsl:attribute name="icon">close</xsl:attribute>
				<xsl:attribute name="text"><xsl:value-of select="$inchorus_button_terminate" /></xsl:attribute>
				<xsl:attribute name="highlighting">low</xsl:attribute>
				<xsl:attribute name="active">true</xsl:attribute>
			</inchorus-button>
			
		</inchorus-form>

	</xsl:template>
</xsl:stylesheet>