<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<!--
*
*	Date 	    Programmer		 Version		Description
*	~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*	07/30/2014	Sebastian Radau  	1.0.0		Created 
*	12/20/2016	Thomas Gertler  	1.1.0		webcomponents compatiblity 
*												
*	Copyright (c) G+H Systems GmbH, 2014
*	
*	This development kit is proprietary to G+H Systems GmbH.	
*	All rights reserved. For more information visit the website:
*   www.inchorus.de	
*							
*************************************************************************/-->

	<!-- Output Definition - Beginning -->
	<xsl:output method="html" encoding="<!--GADGET:ENCODING-->" />	
	<!-- Output Definition - End -->

	<!-- Language File Include - Beginning -->
	<xsl:include href="<!--GADGET:LANGUAGE-->/language_webcomponents.xsl" />
	<xsl:include href="<!--GADGET:LANGUAGE-->/language_person.xsl" />
	<xsl:include href="<!--GADGET:LANGUAGE-->/language.xsl" />
	
	<!-- Language File Include - End -->
	
	<!-- Gadget Variables File Include - Beginning -->
	<xsl:include href="gadget_variables.xsl" />
	<!-- Gadget Variables File Include - End -->
	
	<xsl:template match="data">
		<xsl:variable name="managerid" select="//parameters/parameter[@name='managerid']" />
		<xsl:variable name="nextlevel" select="//parameters/parameter[@name='nextlevel']" />
		<xsl:variable name="subfolder" select="//parameters/parameter[@name='subfolder']" />
		<xsl:variable name="treeprefix">exchange-admin-general-effective-tree-nextrow</xsl:variable>
	  	<xsl:variable name="parentid" select="//data/parameters/parameter[@name='parentid']"/>
	 	<xsl:variable name="countentries" select="count(//members/member)" />
	 	
	 	
		<xsl:variable name="uniqueidsecurityprincipal" select="//parameters/parameter[@name='uniqueidsecurityprincipal']"/>
		<xsl:variable name="modus" select="//parameters/parameter[@name='modus']"/>
		<xsl:variable name="adusername" select="//parameters/parameter[@name='adusername']" />

		<xsl:choose>
			<xsl:when test="//members/member">
				<xsl:for-each select="//members/member">
					<xsl:variable name="uniqueid" select="uniqueid" />
					<xsl:variable name="name" select="name" />
					<xsl:variable name="category" select="category" />
					<xsl:variable name="isowner" select="isowner" />
					<xsl:variable name="systemid" select="systemid" />
					<xsl:variable name="systemname" select="systemname" />
					
					<xsl:variable name="position" select="position()" />
					<xsl:variable name="subfoldercount" select="subfoldercount" />

					<inchorus-tree-row class="flex-container" style="display: flex; flex-wrap: nowrap; font-weight:bold;">
						<xsl:choose>
							<xsl:when test="$isowner = '1'">
								<xsl:attribute name="style">display: flex; flex-wrap: nowrap; font-weight:bold;</xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="style">display: flex; flex-wrap: nowrap;</xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
						<xsl:attribute name="id"><xsl:value-of select="$treeprefix" />-entry-<xsl:value-of select="$uniqueid" />-parent-<xsl:value-of select="$parentid" /></xsl:attribute>
						
						<inchorus-tree-row-header>
							<xsl:choose>
								<xsl:when test="$modus='effectiveview_aduser'">
									<xsl:attribute name="style">width: calc(100% - 600px);padding: 7px 10px;</xsl:attribute>
								</xsl:when>
								<xsl:otherwise>
									<xsl:attribute name="style">width:1272px;min-width:1272px;padding: 7px 10px;</xsl:attribute>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:attribute name="backgroundcode"><xsl:value-of select="$countentries" />-<xsl:value-of select="$position" /></xsl:attribute>
							
							<inchorus-tree-button>
						  		<xsl:attribute name="id"><xsl:value-of select="$treeprefix" />-button-<xsl:value-of select="$uniqueid" /></xsl:attribute>
						  		<xsl:attribute name="type">text</xsl:attribute>
								<xsl:attribute name="text">&#160;</xsl:attribute>
								<xsl:attribute name="class">msfileserver-tree-icon-folder-0</xsl:attribute>
								
								<xsl:choose>
									<xsl:when test="subfoldercount != '0'">
										<xsl:attribute name="onclick">
											inchorus.$('<xsl:value-of select="$treeprefix" />-entry-<xsl:value-of select="$uniqueid" />-parent-<xsl:value-of select="$parentid" />-nextlevel').setParameters(
												{
													parentid: '<xsl:value-of select="$uniqueid"/>',
													uniqueidsecurityprincipal: '<xsl:value-of select="$uniqueidsecurityprincipal"/>',
													nextlevel: '2',
													modus: '<xsl:value-of select="$modus" />'
												}
											);
											inchorus.$("<xsl:value-of select="$treeprefix" />-button-<xsl:value-of select="$uniqueid" />").toggleActive();
											inchorus.$("<xsl:value-of select="$treeprefix" />-entry-<xsl:value-of select="$uniqueid" />-parent-<xsl:value-of select="$parentid" />-nextlevel").toggleActive();
										</xsl:attribute>
									</xsl:when>
									<xsl:otherwise>
										<xsl:attribute name="class">noicon</xsl:attribute>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:attribute name="border">false</xsl:attribute>
								<xsl:attribute name="parameters">[{"parentid":"<xsl:value-of select="$uniqueid" />"}]</xsl:attribute>
						  	</inchorus-tree-button>
						  	
						  	<div style="cursor:pointer;">
						  		<xsl:choose>
						  			<xsl:when test="$subfolder='mailboxes'">
						  				<xsl:attribute name="onClick">
						  					type = jQuery("#exchange-admin-effective-filter-field-securityprincipallabel").val();
											userorgroup = jQuery("#exchange-admin-effective-filter-field-effectiveusers").val();

											$('#' + $('.active_row').attr("id")).removeClass('active_row');
											$('#' + $(this).parent().parent().attr('id')).addClass('active_row');
											
						  					exchange.slider.showDetails(
												'small',
												{
													'objecttype':'mailbox',
													'header' : '<xsl:value-of select="$name"/>',
													'uniqueid' : '<xsl:value-of select="$uniqueid"/>',
													'uniqueidsecurityprincipal' : '<xsl:value-of select="$uniqueidsecurityprincipal"/>',
													'systemid' : '<xsl:value-of select="$systemid"/>',
													'modus' : '<xsl:value-of select="$modus" />'
												}
											);	
						  				</xsl:attribute>
						  			</xsl:when>
						  			<xsl:otherwise>
								  		<xsl:attribute name="onClick">
											type = jQuery("#exchange-admin-effective-filter-field-securityprincipallabel").val();
											userorgroup = jQuery("#exchange-admin-effective-filter-field-effectiveusers").val();
		
											$('#' + $('.active_row').attr("id")).removeClass('active_row');
											$('#' + $(this).parent().parent().attr('id')).addClass('active_row');
																	
											exchange.slider.showDetails(
												'small',
												{
													'objecttype':'distributiongroup',
													'header' : '<xsl:value-of select="$name"/>',
													'uniqueid' : '<xsl:value-of select="$uniqueid"/>',
													'uniqueidsecurityprincipal' : '<xsl:value-of select="$uniqueidsecurityprincipal"/>',
													'systemid' : '<xsl:value-of select="$systemid"/>',
													'moduslol' : '<xsl:value-of select="$modus" />'
												}
											);	
											
										</xsl:attribute>
						  			</xsl:otherwise>
						  		</xsl:choose>
						  		
								
								<xsl:choose>
									<xsl:when test="$category = 'UserMailbox'">
										<div class="rowname" style="padding-left:0px;color:#666 !important;">
											<xsl:attribute name="title"><xsl:value-of select="$uniqueid" /></xsl:attribute>
											<div class="exchange-tree-icon exchange-tree-icon-mailbox">
												<xsl:attribute name="title"><xsl:value-of select="$category" /></xsl:attribute>
    											<div class="exchange-tree-icon-mailbox-additive exchange-tree-icon-mailbox-additive-user" />
											</div>
											<xsl:value-of select="$name" />
										</div>
									</xsl:when>
									<xsl:when test="$category = 'DiscoveryMailbox'">
										<div class="rowname" style="padding-left:0px;color:#666 !important;">
											<xsl:attribute name="title"><xsl:value-of select="$uniqueid" /></xsl:attribute>
											<div class="exchange-tree-icon exchange-tree-icon-mailbox">
												<xsl:attribute name="title"><xsl:value-of select="$category" /></xsl:attribute>
    											<div class="exchange-tree-icon-mailbox-additive exchange-tree-icon-mailbox-additive-discovery" />
											</div>
											<xsl:value-of select="$name" />
										</div>
									</xsl:when>
									<xsl:when test="$category = 'SharedMailbox'">
										<div class="rowname" style="padding-left:0px;color:#666 !important;">
											<xsl:attribute name="title"><xsl:value-of select="$uniqueid" /></xsl:attribute>
											<div class="exchange-tree-icon exchange-tree-icon-mailbox">
												<xsl:attribute name="title"><xsl:value-of select="$category" /></xsl:attribute>
    											<div class="exchange-tree-icon-mailbox-additive exchange-tree-icon-mailbox-additive-shared" />
											</div>
											<xsl:value-of select="$name" />
										</div>
									</xsl:when>
									<xsl:when test="$category = 'RoomMailbox'">
										<div class="rowname" style="padding-left:0px;color:#666 !important;">
											<xsl:attribute name="title"><xsl:value-of select="$uniqueid" /></xsl:attribute>
											<div class="exchange-tree-icon exchange-tree-icon-mailbox">
												<xsl:attribute name="title"><xsl:value-of select="$category" /></xsl:attribute>
    											<div class="exchange-tree-icon-mailbox-additive exchange-tree-icon-mailbox-additive-resources" />
											</div>
											<xsl:value-of select="$name" />
										</div>
									</xsl:when>
									<xsl:when test="$category = 'MailUniversalDistributionGroup' or $category = 'MailUniversalSecurityGroup'">
										<div class="rowname" style="padding-left:0px;color:#666 !important;">
											<xsl:attribute name="title"><xsl:value-of select="$uniqueid" /></xsl:attribute>
											<div class="exchange-tree-icon exchange-tree-icon-distributionlist">
												<xsl:attribute name="title"><xsl:value-of select="$category" /></xsl:attribute>
    											<!-- <div class="exchange-tree-icon-distributionlist-additive exchange-tree-icon-distributionlist-additive-shared" /> -->
											</div>
											<xsl:value-of select="$name" />
										</div>
									</xsl:when>
									<xsl:when test="$category = 'DynamicDistributionGroup'">
										<div class="rowname" style="padding-left:0px;color:#666 !important;">
											<xsl:attribute name="title"><xsl:value-of select="$uniqueid" /></xsl:attribute>
											<div class="exchange-tree-icon exchange-tree-icon-distributionlist">
												<xsl:attribute name="title"><xsl:value-of select="$category" /></xsl:attribute>
    											<div class="exchange-tree-icon-distributionlist-additive exchange-tree-icon-distributionlist-additive-dynamic" />
											</div>
											<xsl:value-of select="$name" />
										</div>
									</xsl:when>
								</xsl:choose>
							</div>
						  					
						</inchorus-tree-row-header>  
						
						<inchorus-tree-row-content style="min-width:348px;overflow:hidden;display: flex; flex-wrap: nowrap; color:#666 !important;padding: 7px 0px;cursor:pointer;">	
							<div class="rowname" style="float:left;font-size:10pt;color:#666;line-height:34px; right:20px;cursor:default;">								
								<!-- 
								<xsl:attribute name="title">Der letzte Collector-Lauf wurde am 01.12.2019 um 13:00 Uhr ausgeführt.</xsl:attribute>
								Stand vom: 01.12.2019 13:00
								-->
								<!-- <xsl:value-of select="$systemname"/> -->
								<xsl:value-of select="$name" />
						</div>
						</inchorus-tree-row-content>									
					</inchorus-tree-row>
					<inchorus-tree-row-nextlevel style="overflow:hidden; height:auto;width:100%;">
						<xsl:attribute name="id"><xsl:value-of select="$treeprefix" />-entry-<xsl:value-of select="$uniqueid" />-parent-<xsl:value-of select="$parentid" />-nextlevel</xsl:attribute>
						<xsl:attribute name="active">false</xsl:attribute>
						<xsl:attribute name="hascontentfile">true</xsl:attribute>			
						<xsl:attribute name="alternativecontentfile">exchange-admin-general-effective-tree-nextrow</xsl:attribute>
						<xsl:attribute name="activationcontentmode">always</xsl:attribute>
						<xsl:attribute name="deactivationcontentmode">remove</xsl:attribute>
						<xsl:attribute name="nextlevel"><xsl:value-of select="2" /></xsl:attribute>
						<xsl:attribute name="command">getFolderContentForSecurityprincipal</xsl:attribute>
					</inchorus-tree-row-nextlevel>
					
				</xsl:for-each>
			</xsl:when>
			<xsl:when test="//counts/count">
				<xsl:choose>
					<xsl:when test="not(//counts/count) and not($parentid)">
						 <inchorus-message>
						 	<xsl:attribute name="id"><xsl:value-of select="$treeprefix" />-message-noresult</xsl:attribute>
						   	<xsl:attribute name="type">node</xsl:attribute>
						    <xsl:attribute name="active">true</xsl:attribute>
						    <xsl:value-of select="$inchorus_list_message_noresults"/>
						 </inchorus-message>
					</xsl:when>
					<xsl:otherwise>
						<xsl:for-each select="//counts/count">
						  	<xsl:variable name="mailboxCnt" select="mailboxCnt" />
						  	<xsl:variable name="distributiongroupCnt" select="distributiongroupCnt" />
						  	
						  	<xsl:variable name="position" select="position()" />

						  			<inchorus-tree-row class="flex-container" style="display: flex; flex-wrap: nowrap;">
										<xsl:attribute name="id"><xsl:value-of select="$treeprefix" />-mailboxes</xsl:attribute>
										<xsl:attribute name="position">1</xsl:attribute>
										
										<div>
											<inchorus-tree-row-header style="width:1272px;min-width:1272px;padding: 7px 10px;">
												<xsl:attribute name="backgroundcode"><xsl:value-of select="$countentries" />-<xsl:value-of select="$position" /></xsl:attribute>
												
												<inchorus-tree-button>
													<xsl:attribute name="id"><xsl:value-of select="$treeprefix" />-button-mailboxes</xsl:attribute>
													<xsl:attribute name="type">text</xsl:attribute>
													<xsl:attribute name="text">&#160;</xsl:attribute>
													<xsl:attribute name="onclick">
														inchorus.$('<xsl:value-of select="$treeprefix" />-entry-mailboxes-nextlevel').setParameters(
															{
																modus: 'effectiveview_aduser',
																subfolder: 'mailboxes',
																uniqueidsecurityprincipal: "<xsl:value-of select="$uniqueidsecurityprincipal" />"
															}
														);
														inchorus.$("<xsl:value-of select="$treeprefix" />-button-mailboxes").toggleActive();
														inchorus.$("<xsl:value-of select="$treeprefix" />-entry-mailboxes-nextlevel").toggleActive();
													</xsl:attribute>
													<xsl:attribute name="border">false</xsl:attribute>
												</inchorus-tree-button>
												<xsl:value-of select="$exchange_effectiveusers_level_mailboxes" />
											</inchorus-tree-row-header>
										</div>
									</inchorus-tree-row>
									<inchorus-tree-row-nextlevel style="overflow:hidden; height:auto;">
											<xsl:attribute name="id"><xsl:value-of select="$treeprefix" />-entry-mailboxes-nextlevel</xsl:attribute>
											<xsl:attribute name="active">false</xsl:attribute>
											<xsl:attribute name="hascontentfile">true</xsl:attribute>
											<xsl:attribute name="alternativecontentfile">exchange-admin-general-effective-tree-nextrow</xsl:attribute>
											<xsl:attribute name="activationcontentmode">always</xsl:attribute>
											<xsl:attribute name="deactivationcontentmode">remove</xsl:attribute>
											<xsl:attribute name="style">display:block;width:100%;overflow:hidden; height:auto;</xsl:attribute>
											<xsl:attribute name="command">getExchangeRelationsForUser</xsl:attribute>
									</inchorus-tree-row-nextlevel>
									
									<inchorus-tree-row class="flex-container" style="display: flex; flex-wrap: nowrap;">
										<xsl:attribute name="id"><xsl:value-of select="$treeprefix" />-distributiongroups</xsl:attribute>
										<xsl:attribute name="position">2</xsl:attribute>
										
										<div>
											<inchorus-tree-row-header style="width:1272px;min-width:1272px;padding: 7px 10px;">
												<xsl:attribute name="class">level-0 inchorus-tree-level-0-last</xsl:attribute>
												<!-- <xsl:attribute name="class">inchorus-tree-level-<xsl:value-of select="$nextlevel" />-lastcell</xsl:attribute> -->
												
												<inchorus-tree-button>
													<xsl:attribute name="id"><xsl:value-of select="$treeprefix" />-button-distributiongroups</xsl:attribute>
													<xsl:attribute name="type">text</xsl:attribute>
													<xsl:attribute name="text">&#160;</xsl:attribute>
													<xsl:attribute name="onclick">
														inchorus.$('<xsl:value-of select="$treeprefix" />-entry-distributiongroups-nextlevel').setParameters(
															{
																modus: 'effectiveview_aduser',
																subfolder: 'distributiongroups',
																uniqueidsecurityprincipal: "<xsl:value-of select="$uniqueidsecurityprincipal" />"
															}
														);
														inchorus.$("<xsl:value-of select="$treeprefix" />-button-distributiongroups").toggleActive();
														inchorus.$("<xsl:value-of select="$treeprefix" />-entry-distributiongroups-nextlevel").toggleActive();
													</xsl:attribute>
													<xsl:attribute name="border">false</xsl:attribute>
												</inchorus-tree-button>
												<xsl:value-of select="$exchange_effectiveusers_level_distributiongroups" />
											</inchorus-tree-row-header>
										</div>
									</inchorus-tree-row>
									<inchorus-tree-row-nextlevel style="overflow:hidden; height:auto;">
											<xsl:attribute name="id"><xsl:value-of select="$treeprefix" />-entry-distributiongroups-nextlevel</xsl:attribute>
											<xsl:attribute name="active">false</xsl:attribute>
											<xsl:attribute name="hascontentfile">true</xsl:attribute>
											<xsl:attribute name="alternativecontentfile">exchange-admin-general-effective-tree-nextrow</xsl:attribute>
											<xsl:attribute name="activationcontentmode">always</xsl:attribute>
											<xsl:attribute name="deactivationcontentmode">remove</xsl:attribute>
											<xsl:attribute name="style">display:block;width:100%;overflow:hidden; height:auto;</xsl:attribute>
											<xsl:attribute name="command">getExchangeRelationsForUser</xsl:attribute>
									</inchorus-tree-row-nextlevel>
						  		</xsl:for-each>
							</xsl:otherwise>
					</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="$subfolder = 'mailboxes'">
						<inchorus-message>       
							<xsl:attribute name="id"><xsl:value-of select="$parentid" />-message-noresults-mailboxes</xsl:attribute>       
							<xsl:attribute name="active">true</xsl:attribute>       
							<xsl:attribute name="type">node</xsl:attribute>       
							<xsl:value-of select="$exchange_effectiveusers_message_no_result_mailbox" />      
						</inchorus-message>
					</xsl:when>
					<xsl:otherwise>
						<inchorus-message>       
							<xsl:attribute name="id"><xsl:value-of select="$parentid" />-message-noresults-distributiongroups</xsl:attribute>       
							<xsl:attribute name="active">true</xsl:attribute>       
							<xsl:attribute name="type">node</xsl:attribute>       
							<xsl:value-of select="$exchange_effectiveusers_message_no_result_distributiongroup" />      
						</inchorus-message>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>
</xsl:stylesheet>