<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<!--
*
*	Date 	    Programmer		 Version		Description
*	~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*	07/30/2014	Sebastian Radau  	1.0.0		Created 
*	12/20/2016	Thomas Gertler  	1.1.0		webcomponents compatiblity 
*												
*	Copyright (c) G+H Systems GmbH, 2014
*	
*	This development kit is proprietary to G+H Systems GmbH.	
*	All rights reserved. For more information visit the website:
*   www.inchorus.de	
*							
*************************************************************************/-->

	<!-- Output Definition - Beginning -->
	<xsl:output method="html" encoding="<!--GADGET:ENCODING-->" />	
	<!-- Output Definition - End -->

	<!-- Language File Include - Beginning -->
	<xsl:include href="<!--GADGET:LANGUAGE-->/language_setup.xsl" />
	<!-- Language File Include - End -->
	
	<!-- Gadget Variables File Include - Beginning -->
	<xsl:include href="gadget_variables.xsl" />
	<!-- Gadget Variables File Include - End -->
	
	<xsl:template match="data">
		<xsl:variable name="id" select="//data/connector/id" />
		<xsl:variable name="name" select="//data/connector/name" />
		<xsl:variable name="description" select="//data/connector/description" />
		<xsl:variable name="position_local_from_this" select="//data/connector/position_local_from_this" />
		<xsl:variable name="statusmessage" select="//data/connector/statusmessage" />
		<xsl:variable name="statuscode" select="//data/status/code" />
		<xsl:variable name="url" select="//data/connector/url" />
		<xsl:variable name="version" select="//data/connector/version" />
		<xsl:variable name="parentid">exchange-systemsetup-connector-addedconnectors</xsl:variable>

		<xsl:choose>
			<xsl:when test="$statuscode = 'SUCCESS_CONNECTOR_RESTART'">
				<script>
					inchorus.$('exchange-systemsetup-connector-addedconnectors').load();
				</script>
			</xsl:when>
			<xsl:otherwise>
				<div class="dac-system-box">
					<xsl:choose>
						<xsl:when test="$statusmessage = 'SUCCESS_CONNECTOR_READY'">
							<xsl:attribute name="class">dac-system-box dac-system-box-success</xsl:attribute>
						</xsl:when>
						<xsl:when test="$statusmessage = 'SUCCESS_CONNECTOR_INIT'">
							<xsl:attribute name="class">dac-system-box dac-system-box-warning</xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="class">dac-system-box dac-system-box-error</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>		
							
					<div style="padding:0px 15px; 15px 20px;">
						<h2  style="margin-bottom:10px;">
							<xsl:attribute name="title"><xsl:value-of select="$description"/></xsl:attribute>
							<xsl:choose>
								<xsl:when test="$statusmessage = 'ERROR_CONNECTOR_NOTCONFIGURED'">
									<xsl:value-of select="$exchange_setup_exchangeconnector" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:choose>
										<xsl:when test="$name= ''">
											<xsl:value-of select="$name" />
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="$exchange_setup_exchangeconnector" />
										</xsl:otherwise>
									</xsl:choose>
								</xsl:otherwise>
							</xsl:choose>
						</h2>
						<div>
							<xsl:choose>
								<xsl:when test="string-length($version) = 3">
									<xsl:value-of select="$exchange_setup_version" />&#160;<xsl:value-of select="substring($version,1,1)"/>.<xsl:value-of select="substring($version,2,1)"/>.<xsl:value-of select="substring($version,3,1)"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="$exchange_setup_version" />&#160;<xsl:value-of select="$version"/>
								</xsl:otherwise>
							</xsl:choose>
						</div>
						<p class="dac-system-box-message" style="font-weight:bold;">
							<xsl:value-of select="$statusmessage" />
						</p>
					</div>
					<div style="border-top: 1px solid #ddd;padding:10px;">
						<inchorus-button class="dac-system-box-button-check">
							<xsl:attribute name="id"><xsl:value-of select="parentid" />-button-check</xsl:attribute>
							<xsl:attribute name="type">text</xsl:attribute>
							<xsl:attribute name="text"><xsl:value-of select="$exchange_setup_button_check" /></xsl:attribute>
							<xsl:attribute name="onclick">
								inchorus.$('<xsl:value-of select="$parentid"/>-button-check').deactivate();
								jQuery('#<xsl:value-of select="$parentid"/>-loading-check').show();
								inchorus.$('<xsl:value-of select="$parentid"/>-form').setParameters(
									{
										"id":"<xsl:value-of select='$id'/>",
										"url":"<xsl:value-of select='$url'/>"
									}
								);
								inchorus.$('<xsl:value-of select="$parentid"/>-form').setResponsetargetid('exchange-systemsetup-connector-addedconnectors-connector-<xsl:value-of select="$id"/>');
								inchorus.$('<xsl:value-of select="$parentid"/>-form').setCommand('checkExchangeConnector');
								inchorus.$('<xsl:value-of select="$parentid"/>-form').submit();
							</xsl:attribute>
						</inchorus-button>
						<img class="dac-system-box-loading">
							<xsl:attribute name="id"><xsl:value-of select="$parentid"/>-loading-check</xsl:attribute>
							<xsl:attribute name="style">display:none;float:left;</xsl:attribute>
							<xsl:attribute name="src">inc/img/loading.gif</xsl:attribute>
						</img>
						<inchorus-button class="dac-system-box-button-restart">
							<xsl:attribute name="id"><xsl:value-of select="parentid" />-button-add-<xsl:value-of select="$id" /></xsl:attribute>
							<xsl:attribute name="type">text</xsl:attribute>
							<xsl:attribute name="icon">refresh</xsl:attribute>
							<xsl:attribute name="text"><xsl:value-of select="$exchange_setup_button_restart" /></xsl:attribute>
							<xsl:attribute name="onclick">
								inchorus.$('<xsl:value-of select="$parentid"/>-form').setParameters(
									{
										"id":"<xsl:value-of select='$id'/>",
										"url":"<xsl:value-of select='$url'/>"
									}
								);
								inchorus.$('<xsl:value-of select="$parentid"/>-form').setResponsetargetid('<xsl:value-of select="$parentid"/>-response');
								inchorus.$('<xsl:value-of select="$parentid"/>-form').setCommand('restartExchangeConnector');
								inchorus.$('<xsl:value-of select="parentid" />-button-add-<xsl:value-of select="$id" />').deactivate();
								jQuery('#<xsl:value-of select="$parentid"/>-loading-<xsl:value-of select="$id" />').show();
								inchorus.$('<xsl:value-of select="$parentid"/>-form').submit();
							</xsl:attribute>
						</inchorus-button>
						<img class="dac-system-box-loading">
							<xsl:attribute name="id"><xsl:value-of select="$parentid"/>-loading-<xsl:value-of select="$id" /></xsl:attribute>
							<xsl:attribute name="style">display:none;</xsl:attribute>
							<xsl:attribute name="src">inc/img/loading.gif</xsl:attribute>
						</img>
					</div>
				</div>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>