<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<!--
*
*	Date 	    Programmer		 Version		Description
*	~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*	07/30/2014	Sebastian Radau  	1.0.0		Created 
*	12/20/2016	Thomas Gertler  	1.1.0		webcomponents compatiblity 
*												
*	Copyright (c) G+H Systems GmbH, 2014
*	
*	This development kit is proprietary to G+H Systems GmbH.	
*	All rights reserved. For more information visit the website:
*   www.inchorus.de	
*							
*************************************************************************/-->

	<!-- Output Definition - Beginning -->
	<xsl:output method="html" encoding="<!--GADGET:ENCODING-->" />	
	<!-- Output Definition - End -->

	<!-- Language File Include - Beginning -->
	<xsl:include href="<!--GADGET:LANGUAGE-->/language_setup.xsl" />
	<!-- Language File Include - End -->
	
	<!-- Gadget Variables File Include - Beginning -->
	<xsl:include href="gadget_variables.xsl" />
	<!-- Gadget Variables File Include - End -->
	
	<xsl:template match="data">
		<xsl:variable name="parentid">exchange-systemsetup-system-addedsystems-lightbox</xsl:variable>
		<xsl:variable name="name" select="//data/parameters/parameter[@name='name']" />
		<xsl:variable name="systemid" select="//data/parameters/parameter[@name='systemid']" />
		<xsl:variable name="state" select="//data/parameters/parameter[@name='state']" />
		<xsl:variable name="grandparentid" select="//data/parameters/parameter[@name='grandparentid']" />
		<xsl:variable name="boxcontentid" select="//data/parameters/parameter[@name='boxcontentid']" />
		<xsl:variable name="count_running" select="count(//data/collectors/collector/state[text() = 'running'])" />
		<script>
			var count_running = '<xsl:value-of select="$count_running" />';
			var active = jQuery('#exchange-systemsetup-system-addedsystems-lightbox').attr('active');
			if (count_running > 0 &amp;&amp; active == 'true') {
				setTimeout(function(){
					inchorus.$('exchange-systemsetup-system-addedsystems-lightbox').load();
				}, 3000);
			};
		</script>
		<h3>
			<xsl:value-of select="$exchange_setup_system_lightbox_collectors_header" />&#160;"<xsl:value-of select="$name" />"
		</h3>
		<div class="inchorus-lightbox-options">
			
			<!-- lightbox close button start -->
			<inchorus-button id="exchange-systemsetup-lightbox-button-close">
				<xsl:attribute name="type">icon</xsl:attribute>
				<xsl:attribute name="icon">close</xsl:attribute>
				<xsl:attribute name="border">false</xsl:attribute>
				<xsl:attribute name="highlighting">none</xsl:attribute>
				<xsl:attribute name="hover">false</xsl:attribute>
				<xsl:attribute name="active">true</xsl:attribute>
				<xsl:attribute name="title"><xsl:value-of select="$exchange_setup_button_close" /></xsl:attribute>
				<xsl:attribute name="onclick">
					inchorus.$('<xsl:value-of select="$parentid"/>').deactivate();
					inchorus.$('<xsl:value-of select="$grandparentid" />').load();
				</xsl:attribute>
		 	</inchorus-button>
			<!-- lightbox close button end -->
		</div>
		
		<div>
			<xsl:attribute name="id"><xsl:value-of select="$parentid"/>-response</xsl:attribute>
		</div>
		
		<div style="padding: 20px;height:615px; overflow:auto;width:958px;">
			<xsl:choose>
				<xsl:when test="//data/collectors/collector">
					<xsl:for-each select="//data/collectors/collector">
						<xsl:variable name="collectorid" select="collectorid" />
						<xsl:variable name="collectorname" select="name" />
						<xsl:variable name="position_mod" select="position() mod 2" />
						<xsl:variable name="nextruntime" select="nextruntime" />
						<xsl:variable name="laststarttime" select="laststarttime" />
						<xsl:variable name="lastendtime" select="lastendtime" />
						<xsl:variable name="schedule" select="schedule" />
						<xsl:variable name="result" select="result" />
						<xsl:variable name="resultcode" select="resultcode" />
						<xsl:variable name="status" select="status" />
						<xsl:variable name="state" select="state" />
						<xsl:variable name="totalcollectionsteps" select="totalcollectionsteps" />
						<xsl:variable name="currentcollectionstep" select="currentcollectionstep" />
						<xsl:variable name="processpercentage" select="processpercentage" />
						<xsl:variable name="subcollectorcount" select="subcollectorcount" />
						<xsl:variable name="lastruntime" select="lastruntime" />
						<xsl:variable name="lastruntime_seconds" select="lastruntime_seconds" />
						<xsl:variable name="lastruntime_minutes" select="lastruntime_minutes" />
						<xsl:variable name="lastruntime_hours" select="lastruntime_hours" />
						<xsl:variable name="lastruntime_days" select="lastruntime_days" />
						<xsl:variable name="tempprocesspercentage" select="number($currentcollectionstep) * 100 div number($totalcollectionsteps) - 5" />
						<xsl:variable name="position" select="position()" />
						<inchorus-content>
							<xsl:attribute name="id">exchange-systemsetup-system-addedsystems-system-collector-<xsl:value-of select="$collectorid"/></xsl:attribute>
							
							<div>
								<xsl:choose>
									<xsl:when test="$state = 'running'">
										<xsl:attribute name="class">dac-system-box-collectors dac-system-box-warning</xsl:attribute>
									</xsl:when>
									<xsl:when test="$lastendtime = 'null' or $lastendtime =''">
										<xsl:attribute name="class">dac-system-box-collectors dac-system-box-notread</xsl:attribute>
									</xsl:when>
									<xsl:when test="$result = 'success'">
										<xsl:attribute name="class">dac-system-box-collectors dac-system-box-success</xsl:attribute>
									</xsl:when>
									<xsl:when test="$result = 'error'">
										<xsl:attribute name="class">dac-system-box-collectors dac-system-box-error</xsl:attribute>
									</xsl:when>
									<xsl:otherwise>
										<xsl:attribute name="class">dac-system-box-collectors dac-system-box-otherwise</xsl:attribute>
									</xsl:otherwise>
								</xsl:choose>
								
								<xsl:if test="$position_mod != 0">
									<xsl:attribute name="style">margin-right:10px;</xsl:attribute>
								</xsl:if>
								
								<div style="padding:0px 15px; 15px 20px;">
									<h2  style="margin-bottom:10px;">
										<xsl:value-of select="$collectorname" />
									</h2>
									<div style="margin-bottom:10px;cursor:default;font-weight:bold;">
										<xsl:attribute name="title"><xsl:value-of select="$resultcode"/></xsl:attribute>
										<xsl:choose>
											<xsl:when test="$state = 'running'">
												<xsl:attribute name="class">textcolor_yellow</xsl:attribute>
												<xsl:value-of select="$exchange_setup_message_updated_running"/>
											</xsl:when>
											<xsl:when test="$lastendtime = 'null' or $lastendtime =''">
												<xsl:attribute name="class">textcolor_grey</xsl:attribute>
												<xsl:value-of select="$exchange_setup_message_updated_warning"/>
											</xsl:when>
											<xsl:when test="$result = 'success'">
												<xsl:attribute name="class">textcolor_green</xsl:attribute>
												<xsl:value-of select="$exchange_setup_message_updated_success"/>
											</xsl:when>
											<xsl:when test="$result = 'error'">
												<xsl:attribute name="class">textcolor_red</xsl:attribute>
												<xsl:value-of select="$exchange_setup_message_updated_error"/>
											</xsl:when>
										</xsl:choose>
									</div>
									
									<xsl:if test="$result = 'error'">
										<div style="color:#de536f;margin-bottom:8px;">
											<xsl:choose>
												<xsl:when test="$resultcode = 'ERROR_WRONG_CONNECTORVERSION'">
													<xsl:value-of select="$exchange_setup_message_error_wrong_connectorversion" />
												</xsl:when>
												<xsl:when test="$resultcode = 'ERROR_WRONG_COLLECTORPATH'">
													<xsl:value-of select="$exchange_setup_message_error_wrong_collectorpath" />
												</xsl:when>
												<xsl:when test="$resultcode = 'ERROR_NO_CONNECTOR'">
													<xsl:value-of select="$exchange_setup_message_error_no_connector" />
												</xsl:when>
												<xsl:when test="$resultcode = 'ERROR_CONNECTOR_NOLICENSE'">
													<xsl:value-of select="$exchange_setup_message_error_connector_nolicense" />
												</xsl:when>
												<xsl:when test="$resultcode = 'ERROR_GENERAL'">
													<xsl:value-of select="$exchange_setup_message_error_general" />
												</xsl:when>
												<xsl:when test="$resultcode = 'POWERSHELL_ERROR_MAPPING'">
													<xsl:value-of select="$exchange_setup_message_error_mapping" />
												</xsl:when>
												<xsl:when test="$resultcode = 'POWERSHELL_ERROR_RIGHTSSCANNER'">
													<xsl:value-of select="$exchange_setup_message_error_rightsscanner" />
												</xsl:when>
												<xsl:when test="$resultcode = 'POWERSHELL_ERROR'">
													<xsl:value-of select="$exchange_setup_message_error_powershell" />
												</xsl:when>
												<xsl:when test="$resultcode = 'POWERSHELL_ERROR_COPY_DATAFILE'">
													<xsl:value-of select="$exchange_setup_message_error_copy_datafile" />
												</xsl:when>
												<xsl:when test="$resultcode = 'ERROR_UPDATE_GRAPH'">
													<xsl:value-of select="$exchange_setup_message_error_update_graph" />
												</xsl:when>
											</xsl:choose>
										</div>
									</xsl:if>
									
									<div class="progress">
										<xsl:attribute name="title"><xsl:value-of select="$processpercentage" />%</xsl:attribute>
										<div class="progress-bar">
											<xsl:choose>
												<xsl:when test="$state = 'running'">
													<xsl:attribute name="class">progress-bar dac-system-progress-warning</xsl:attribute>
													<xsl:attribute name="style">width:<xsl:value-of select="$tempprocesspercentage" />%;</xsl:attribute>
												</xsl:when>
												<xsl:when test="$lastendtime = 'null' or $lastendtime =''">
													<xsl:attribute name="class">progress-bar dac-system-progress-notread</xsl:attribute>
													<xsl:attribute name="style">width:<xsl:value-of select="$processpercentage" />%;</xsl:attribute>
												</xsl:when>
											<!-- 
												<xsl:when test="$state = 'open'">
													<xsl:attribute name="class">progress-bar dac-system-progress-notread</xsl:attribute>
												</xsl:when>
											-->	
												<xsl:when test="$result = 'success'">
													<xsl:attribute name="class">progress-bar dac-system-progress-success</xsl:attribute>
													<xsl:attribute name="style">width:100%;</xsl:attribute>
												</xsl:when>
												<xsl:when test="$result = 'error'">
													<xsl:attribute name="class">progress-bar dac-system-progress-error</xsl:attribute>
													<xsl:attribute name="style">width:<xsl:value-of select="$tempprocesspercentage" />%;</xsl:attribute>
												</xsl:when>
											</xsl:choose>
										</div>
									</div>
									<div style="line-height:24px;">
										<xsl:if test="$laststarttime != 'null' and $laststarttime !=''">
											<div style="margin-bottom: 10px;width:65%;float:left;">
												<xsl:if test="$laststarttime != 'null' and $laststarttime !=''">
													<div style="margin-bottom: 10px;">
														<xsl:value-of select="$exchange_setup_box_lastcollect" /><br/>
														<xsl:choose>
															<xsl:when test="'<!--GADGET:LANGUAGE-->' = 'de'">
																<xsl:value-of select="substring($laststarttime,9,2)"/>.<xsl:value-of select="substring($laststarttime,6,2)"/>.<xsl:value-of select="substring($laststarttime,1,4)"/>&#160;<xsl:value-of select="substring($laststarttime,12,8)"/>
															</xsl:when>
															<xsl:otherwise>
																<xsl:value-of select="substring($laststarttime,1,4)"/>-<xsl:value-of select="substring($laststarttime,6,2)"/>-<xsl:value-of select="substring($laststarttime,9,2)"/>&#160;<xsl:value-of select="substring($laststarttime,12,8)"/>
															</xsl:otherwise>
														</xsl:choose>
													</div>
												</xsl:if>
											</div>
											<div>
												<xsl:value-of select="$exchange_setup_runtime" />:&#160;<br/>
												<xsl:choose>
													<xsl:when test="$lastruntime_days &gt; '0'">
														<xsl:value-of select="$lastruntime_days" />&#160;<xsl:value-of select="$exchange_setup_days" />&#160;<xsl:value-of select="$lastruntime_hours" />&#160;<xsl:value-of select="$exchange_setup_hours" />&#160;<xsl:value-of select="$lastruntime_minutes" />&#160;<xsl:value-of select="$exchange_setup_minutes" />&#160;<xsl:value-of select="$lastruntime_seconds" />&#160;<xsl:value-of select="$exchange_setup_seconds" /><br/>
													</xsl:when>
													<xsl:when test="$lastruntime_hours &gt; '0'">
														<xsl:value-of select="$lastruntime_hours" />&#160;<xsl:value-of select="$exchange_setup_hours" />&#160;<xsl:value-of select="$lastruntime_minutes" />&#160;<xsl:value-of select="$exchange_setup_minutes" />&#160;<xsl:value-of select="$lastruntime_seconds" />&#160;<xsl:value-of select="$exchange_setup_seconds" /><br/>
													</xsl:when>
													<xsl:when test="$lastruntime_minutes &gt; '0'">
														<xsl:value-of select="$lastruntime_minutes" />&#160;<xsl:value-of select="$exchange_setup_minutes" />&#160;<xsl:value-of select="$lastruntime_seconds" />&#160;<xsl:value-of select="$exchange_setup_seconds" /><br/>
													</xsl:when>
													<xsl:otherwise>
														<xsl:value-of select="$lastruntime_seconds" />&#160;<xsl:value-of select="$exchange_setup_seconds" /><br/>
													</xsl:otherwise>
												</xsl:choose>
											</div>
										</xsl:if>
										
									</div>
									<p class="dac-system-box-message" style="font-weight:bold;">
										
									</p>
								</div>
								<xsl:if test="$count_running = '0' and state != 'running'">
									<div style="border-top: 1px solid #ddd;padding:10px;">
										<inchorus-button>
											<xsl:attribute name="id"><xsl:value-of select="$parentid"/>-button-run-<xsl:value-of select="$collectorid" /></xsl:attribute>
											<xsl:attribute name="type">text</xsl:attribute>
											<xsl:attribute name="text"><xsl:value-of select="$exchange_setup_button_refreshdata" /></xsl:attribute>
											<xsl:attribute name="style">background-color:transparent;margin-bottom: 10px;float: right;margin-right: 0px;</xsl:attribute>
											<xsl:attribute name="status">enabled</xsl:attribute>
											<xsl:attribute name="onclick">
												inchorus.$('<xsl:value-of select="$parentid"/>-form').setParameters(
													{
														"collectorid":"<xsl:value-of select="$collectorid" />",
														"systemid":"<xsl:value-of select="$systemid"/>",
													}
												);
												inchorus.$('<xsl:value-of select="$parentid"/>-form').setResponsetargetid('<xsl:value-of select="$parentid"/>-response');
												inchorus.$('<xsl:value-of select="$parentid"/>-form').setCommand('runCollectorSingle');
												inchorus.$('<xsl:value-of select="$parentid" />-button-run-<xsl:value-of select="$collectorid" />').setStatus('loading');
												inchorus.$('<xsl:value-of select="$parentid"/>-form').submit();
											</xsl:attribute>
										</inchorus-button>					
									</div>
								</xsl:if>
							</div>
						</inchorus-content>
						<xsl:choose>
							<xsl:when test="$subcollectorcount &gt; '0'">
								<div class="placeholder-subcollector-with-line">
								</div>
							</xsl:when>
							<xsl:otherwise>
								<div class="placeholder-subcollector">
										
								</div>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
				</xsl:when>
			</xsl:choose>
		</div>
		
		<inchorus-form>
			<xsl:attribute name="id"><xsl:value-of select="$parentid"/>-form</xsl:attribute>
			<xsl:attribute name="submitprefix">inc-</xsl:attribute>
			<xsl:attribute name="alternativeresponsefile"><xsl:value-of select="$parentid"/>-response</xsl:attribute>
			<xsl:attribute name="responsetargetid"><xsl:value-of select="$parentid"/>-response</xsl:attribute>
			<xsl:attribute name="hasresponsefile">true</xsl:attribute>
		</inchorus-form>
	</xsl:template>
</xsl:stylesheet>