<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<!--
*
*	Date 	    Programmer		 Version		Description
*	~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*	07/30/2014	Sebastian Radau  	1.0.0		Created 
*	12/20/2016	Thomas Gertler  	1.1.0		webcomponents compatiblity 
*												
*	Copyright (c) G+H Systems GmbH, 2014
*	
*	This development kit is proprietary to G+H Systems GmbH.	
*	All rights reserved. For more information visit the website:
*   www.inchorus.de	
*							
*************************************************************************/-->

	<!-- Output Definition - Beginning -->
	<xsl:output method="html" encoding="<!--GADGET:ENCODING-->" />	
	<!-- Output Definition - End -->

	<!-- Language File Include - Beginning -->
	<xsl:include href="<!--GADGET:LANGUAGE-->/language_setup.xsl" />
	<!-- Language File Include - End -->
	
	<!-- Gadget Variables File Include - Beginning -->
	<xsl:include href="gadget_variables.xsl" />
	<!-- Gadget Variables File Include - End -->
	
	<xsl:template match="data"> 
		<xsl:variable name="parentid">exchange-systemsetup-system-collectors</xsl:variable>
		<xsl:variable name="name" select="//data/parameters/parameter[@name='name']" />
		<xsl:variable name="systemid" select="//data/parameters/parameter[@name='systemid']" />
		
		<div class="dac-system-addedcomponent-header">
			<xsl:value-of select="$exchange_setup_collectorsofthesystem"/> "<xsl:value-of select="$name" />"
		</div>
		<div style="overflow:hidden;width:100%;margin-bottom:40px;">
			<xsl:choose>
				<xsl:when test="//data/collectors/collector">
					<xsl:for-each select="//data/collectors/collector">
						<xsl:variable name="collectorid" select="collectorid" />
						<xsl:variable name="collectorname" select="name" />
						<xsl:variable name="position_mod" select="position() mod 2" />
						<xsl:variable name="nextruntime" select="nextruntime" />
						<xsl:variable name="laststarttime" select="laststarttime" />
						<xsl:variable name="lastendtime" select="lastendtime" />
						<xsl:variable name="schedule" select="schedule" />
						<xsl:variable name="result" select="result" />
						<xsl:variable name="resultcode" select="resultcode" />
						<xsl:variable name="status" select="status" />
						<xsl:variable name="state" select="state" />

						<inchorus-content>	
							<xsl:attribute name="id">exchange-systemsetup-system-addedsystems-system-collector-<xsl:value-of select="$collectorid"/></xsl:attribute>
							
							<div class="dac-system-box">
								<xsl:choose>
									<xsl:when test="$state = 'running'">
										<xsl:attribute name="class">dac-system-box dac-system-box-warning</xsl:attribute>
									</xsl:when>	
									<xsl:when test="$lastendtime = 'null' or $lastendtime =''">
										<xsl:attribute name="class">dac-system-box dac-system-box-warning</xsl:attribute>
									</xsl:when>
									<xsl:when test="$result = 'success'">
										<xsl:attribute name="class">dac-system-box dac-system-box-success</xsl:attribute>
									</xsl:when>
									<xsl:when test="$result = 'error'">
										<xsl:attribute name="class">dac-system-box dac-system-box-error</xsl:attribute>
									</xsl:when>
									<xsl:otherwise>
										<xsl:attribute name="class">dac-system-box dac-system-box-success</xsl:attribute>
									</xsl:otherwise>
								</xsl:choose>
								
								<xsl:if test="$position_mod != 0">
									<xsl:attribute name="style">margin-right:10px;</xsl:attribute>
								</xsl:if>
								
								<div style="padding:0px 15px; 15px 20px;">
									<h2  style="margin-bottom:10px;">
										<xsl:value-of select="$collectorname" />
									</h2>
									<div style="margin-bottom:10px;cursor:default;">
										<xsl:attribute name="title"><xsl:value-of select="$resultcode"/></xsl:attribute>
										<xsl:choose>
											<xsl:when test="$state = 'running'">
												<xsl:attribute name="class">textcolor_yellow</xsl:attribute>
												<xsl:value-of select="$exchange_setup_message_updated_running"/>
											</xsl:when>	
											<xsl:when test="$lastendtime = 'null' or $lastendtime = ''">
												<xsl:attribute name="class">textcolor_yellow</xsl:attribute>
												<xsl:value-of select="$exchange_setup_message_updated_warning"/>
											</xsl:when>
											<xsl:when test="$result = 'success'">
												<xsl:attribute name="class">textcolor_green</xsl:attribute>
												<xsl:value-of select="$exchange_setup_message_updated_success"/>
											</xsl:when>
											<xsl:when test="$result = 'error'">
												<xsl:attribute name="class">textcolor_red</xsl:attribute>
												<xsl:value-of select="$exchange_setup_message_updated_error"/>
											</xsl:when>
										</xsl:choose>
									</div>
									<div style="line-height:24px;">
										<xsl:if test="$lastendtime != 'null' and $lastendtime !=''">
											<div style="margin-bottom: 10px;">
												<xsl:value-of select="$exchange_setup_box_lastcollect" /><br/>
												<xsl:value-of select="$lastendtime" />
											</div>
										</xsl:if>
										<xsl:if test="$status='scheduled'">
											<div style="margin-bottom: 10px;"><xsl:value-of select="$exchange_setup_box_nextcollect" /><br/><xsl:value-of select="$nextruntime" /></div>
											<div>
												<xsl:value-of select="$exchange_setup_box_timeschedule" />&#160;
											</div>
											<div>
												<xsl:attribute name="id">exchange-systemsetup-system-addedsystems-system-collector-<xsl:value-of select="$collectorid"/>-div</xsl:attribute>
												.
											</div>
											<script>
  												var crontext = cronstrue.toString("<xsl:value-of select="$schedule" />", { locale: "<xsl:value-of select="$language" />" });
  												jQuery('#exchange-systemsetup-system-addedsystems-system-collector-<xsl:value-of select="$collectorid"/>-div').text(crontext);
											</script>
										</xsl:if>
									</div>
									<p class="dac-system-box-message" style="font-weight:bold;">
										
									</p>
								</div>
								<xsl:if test="$state != 'running'">
									<div style="border-top: 1px solid #ddd;padding:10px;">
									<!-- 
									<inchorus-button class="dac-system-box-button-check">
										<xsl:attribute name="id"><xsl:value-of select="parentid" />-button-check</xsl:attribute>
										<xsl:attribute name="type">text</xsl:attribute>
										<xsl:attribute name="text"><xsl:value-of select="$exchange_setup_button_check" /></xsl:attribute>
										<xsl:attribute name="onclick">
											inchorus.$('<xsl:value-of select="$parentid"/>-form').setResponsetargetid('exchange-systemsetup-system-addedsystems-system-collector-<xsl:value-of select="$collectorid" />');
											inchorus.$('<xsl:value-of select="$parentid"/>-form').setCommand('checkADSystem');
											inchorus.$('<xsl:value-of select="$parentid"/>-form').submit();
										</xsl:attribute>
									</inchorus-button>
									-->

										<inchorus-button class="dac-system-box-button-restart">
											<xsl:attribute name="id">
												<xsl:value-of select="$parentid"/>-button-add-<xsl:value-of select="$collectorid"/>
											</xsl:attribute>
											<xsl:attribute name="type">icontext</xsl:attribute>
											<xsl:attribute name="icon">refresh</xsl:attribute>
											<xsl:attribute name="text"><xsl:value-of select="$exchange_setup_button_collect" /></xsl:attribute>
											<xsl:attribute name="onclick">
												inchorus.$('exchange-systemsetup-system-collectors-form').setParameters(
													{
														"collectorid":"<xsl:value-of select="$collectorid"/>",
														"systemid":"<xsl:value-of select="$systemid"/>"
													}
												);
												inchorus.$('<xsl:value-of select="$parentid"/>-form').setResponsetargetid('<xsl:value-of select="$parentid"/>-response');
												inchorus.$('<xsl:value-of select="$parentid"/>-form').setCommand('runCollector');
												inchorus.$('<xsl:value-of select="$parentid"/>-button-add-<xsl:value-of select="$collectorid"/>').deactivate();
												jQuery('#<xsl:value-of select="$parentid"/>-loading-<xsl:value-of select="$collectorid" />').show();
												inchorus.$('<xsl:value-of select="$parentid"/>-form').submit();
											</xsl:attribute>
										</inchorus-button>
										<img class="dac-system-box-loading">
											<xsl:attribute name="id"><xsl:value-of select="$parentid"/>-loading-<xsl:value-of select="$collectorid" /></xsl:attribute>
											<xsl:attribute name="style">display:none;</xsl:attribute>
											<xsl:attribute name="src">inc/img/loading.gif</xsl:attribute>
										</img>

									</div>
								</xsl:if>
							</div>
						</inchorus-content>
						
					</xsl:for-each>
				</xsl:when>
				<xsl:otherwise>
					<div style="border: 1px dashed #888;height:173px;margin-bottom:40px;width: 270px;cursor: pointer;">
						<xsl:attribute name="onclick">
							jQuery('#<xsl:value-of select="$parentid" />-lightbox').attr('class','dac-system-lightbox-big');
							inchorus.$('<xsl:value-of select="$parentid" />-lightbox').setAlternativecontentfile('exchange-systemsetup-system-collector-lightbox-host');
							inchorus.$('<xsl:value-of select="$parentid" />-lightbox').activate();
						</xsl:attribute>
						
						<div style="text-align: center;margin-top:75px;">
							<xsl:value-of select="$exchange_setup_system_text_adddcollector"/>
						</div>
						
					</div>
				</xsl:otherwise>
			</xsl:choose>
		</div>		
		<inchorus-lightbox>
			<xsl:attribute name="id"><xsl:value-of select="$parentid" />-lightbox</xsl:attribute>
			<xsl:attribute name="active">false</xsl:attribute>
			<xsl:attribute name="hascontentfile">true</xsl:attribute>
		</inchorus-lightbox>	
		
		<inchorus-form>
			<xsl:attribute name="id"><xsl:value-of select="$parentid"/>-form</xsl:attribute>
			<xsl:attribute name="submitprefix">inc-</xsl:attribute>
			<xsl:attribute name="alternativeresponsefile"><xsl:value-of select="$parentid"/>-response</xsl:attribute>
			<xsl:attribute name="hasresponsefile">true</xsl:attribute>
		</inchorus-form>	
		
		<div>
			<xsl:attribute name="id"><xsl:value-of select="$parentid"/>-response</xsl:attribute>
		</div>	
	</xsl:template>
</xsl:stylesheet>