<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<!--
*
*	Date 	    Programmer		 Version		Description
*	~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*	07/30/2014	Sebastian Radau  	1.0.0		Created 
*	12/20/2016	Thomas Gertler  	1.1.0		webcomponents compatiblity 
*												
*	Copyright (c) G+H Systems GmbH, 2014
*	
*	This development kit is proprietary to G+H Systems GmbH.	
*	All rights reserved. For more information visit the website:
*   www.inchorus.de	
*							
*************************************************************************/-->

	<!-- Output Definition - Beginning -->
	<xsl:output method="html" encoding="<!--GADGET:ENCODING-->" />	
	<!-- Output Definition - End -->

	<!-- Language File Include - Beginning -->
	<xsl:include href="<!--GADGET:LANGUAGE-->/language_setup.xsl" />
	<!-- Language File Include - End -->
	
	<!-- Gadget Variables File Include - Beginning -->
	<xsl:include href="gadget_variables.xsl" />
	<!-- Gadget Variables File Include - End -->
	
	<xsl:template match="data">
		<xsl:variable name="inchorus-form-validity" select="//data/parameters/parameter[@name='inchorus-form-validity']"/>
		<xsl:variable name="statustype" select="//data/status/type" />	
		<xsl:variable name="statuscode" select="//data/status/code" />	
		<xsl:variable name="contentid" select="//session/contentid" />
		<xsl:variable name="statusmessage" select="//data/connectors/connector/statusmessage" />
		<xsl:variable name="connected" select="//data/connection/connected" />
		<xsl:variable name="message" select="//data/connection/message" />
		<xsl:variable name="errorcode" select="//data/connection/errorcode" />
		
		<xsl:variable name="type" select="//data/connection/type" />
		
		<xsl:variable name="domainname" select="//data/connection/domainname" />	
		<xsl:variable name="servername" select="//data/connection/servername" />
		<xsl:variable name="systemname" select="//data/parameters/parameter[@name='systemname']" />
		<xsl:variable name="servertype" select="//data/connection/servertype" />	
		<xsl:variable name="userid" select="//data/connection/userid" />
		<xsl:variable name="userpw" select="//data/connection/userpw" />
		
		<xsl:variable name="tenantname" select="//data/connection/tenantname" />
		<xsl:variable name="organization" select="//data/connection/organization" />
		<xsl:variable name="tenantid" select="//data/connection/tenantid" />
		<xsl:variable name="appid" select="//data/connection/appid" />
		<xsl:variable name="certThumbprint" select="//data/connection/certThumbprint" />

		<script>
			inchorus.$('exchange-systemsetup-system-lightbox-button-check').setStatus('enabled');
		</script>
				
		<xsl:choose>
			<xsl:when test="$inchorus-form-validity='false'">
				<inchorus-message id="config-form-error">
					<xsl:attribute name="type">error</xsl:attribute>
					<xsl:value-of select="$exchange_setup_message_error_validation" />
				</inchorus-message>
			</xsl:when>
			<xsl:when test="$statusmessage='ERROR_CONNECTOR_UNREACHABLE'">
				<inchorus-message id="setup-portal-createportaldb-form-error">
					<xsl:attribute name="type">error</xsl:attribute>
					<xsl:value-of select="$exchange_setup_system_error_connector_unreachable" />
				</inchorus-message>
			</xsl:when>	
			<xsl:when test="$statusmessage='ERROR_CONNECTOR_NODB'">
				<inchorus-message id="setup-portal-createportaldb-form-error">
					<xsl:attribute name="type">error</xsl:attribute>
					<xsl:value-of select="$exchange_setup_system_error_connector_nodb" />
				</inchorus-message>
			</xsl:when>		
			<xsl:when test="$statusmessage='ERROR_CONNECTOR_NOTCONFIGURED'">
				<inchorus-message id="setup-portal-createportaldb-form-error">
					<xsl:attribute name="type">error</xsl:attribute>
					<xsl:value-of select="$exchange_setup_system_error_connector_notconfigured" />
				</inchorus-message>
			</xsl:when>
			<xsl:when test="$statuscode='ERROR_DOMAIN_NOTCONFIGURED'">
				<inchorus-message id="setup-portal-createportaldb-form-error">
					<xsl:attribute name="type">error</xsl:attribute>
					<xsl:value-of select="$exchange_setup_system_lightbox_message_error_host" />
				</inchorus-message>
			</xsl:when>
			<xsl:when test="$statuscode='ERROR_SYSTEM_EXISTS'">
				<inchorus-message id="setup-portal-createportaldb-form-error">
					<xsl:attribute name="type">error</xsl:attribute>
					<xsl:value-of select="$exchange_setup_system_lightbox_message_error_exists" />
				</inchorus-message>
			</xsl:when>
			<xsl:when test="$connected = 'false'">
				<inchorus-message id="setup-portal-createportaldb-form-error">
					<xsl:attribute name="type">error</xsl:attribute>
					<xsl:value-of select="$exchange_setup_system_lightbox_message_error_host" />
				</inchorus-message>
			</xsl:when>
			<xsl:when test="$connected = 'true'">
				<inchorus-message id="setup-portal-createportaldb-form-error">
					<xsl:attribute name="type">success</xsl:attribute>
					<xsl:value-of select="$exchange_setup_system_lightbox_message_success" />
				</inchorus-message>	
				<xsl:choose>
					<xsl:when test="$type = 'online'">
						<script>
							inchorus.$('exchange-systemsetup-system-remotesystems').setParameters(
									{
										"connected":"<xsl:value-of select="$connected"/>",
										"message": "<xsl:value-of select="$message"/>",
										"type":"<xsl:value-of select="$type"/>",
										"tenantname":"<xsl:value-of select="$tenantname"/>",
										"organization":"<xsl:value-of select="$organization"/>",
										"systemname":"<xsl:value-of select="$systemname"/>",
										"tenantid":"<xsl:value-of select="$tenantid"/>",
										"appid":"<xsl:value-of select="$appid"/>",
										"certThumbprint":"<xsl:value-of select="$certThumbprint"/>"
									}
							);
							inchorus.$('exchange-systemsetup-system-remotesystems').setCommand('getDefaultData');
							inchorus.$.delay(1000, "inchorus.$('exchange-systemsetup-system-remotesystems').load();");
							inchorus.$.delay(1000, "inchorus.$('exchange-systemsetup-system-lightbox').deactivate();");					
						</script>
					</xsl:when>
					<xsl:otherwise>
						<script>
							inchorus.$('exchange-systemsetup-system-remotesystems').setParameters(
									{
										"connected":"<xsl:value-of select="$connected"/>",
										"message": "<xsl:value-of select="$message"/>",
										"type":"onpremise",
										"domainname":"<xsl:value-of select="$domainname"/>",
										"servername":"<xsl:value-of select="$servername"/>",
										"systemname":"<xsl:value-of select="$systemname"/>",
										"servertype":"<xsl:value-of select="$servertype"/>",
										"userid":"<xsl:value-of select="$userid"/>",
										"userpw":"<xsl:value-of select="$userpw"/>"
									}
							);
							inchorus.$('exchange-systemsetup-system-remotesystems').setCommand('getDefaultData');
							inchorus.$.delay(1000, "inchorus.$('exchange-systemsetup-system-remotesystems').load();");
							inchorus.$.delay(1000, "inchorus.$('exchange-systemsetup-system-lightbox').deactivate();");					
						</script>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>