<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<!--
*
*	Date 	    Programmer		 Version		Description
*	~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*	07/30/2014	Sebastian Radau  	1.0.0		Created 
*	12/20/2016	Thomas Gertler  	1.1.0		webcomponents compatiblity 
*												
*	Copyright (c) G+H Systems GmbH, 2014
*	
*	This development kit is proprietary to G+H Systems GmbH.	
*	All rights reserved. For more information visit the website:
*   www.inchorus.de	
*							
*************************************************************************/-->

	<!-- Output Definition - Beginning -->
	<xsl:output method="html" encoding="<!--GADGET:ENCODING-->" />	
	<!-- Output Definition - End -->

	<!-- Language File Include - Beginning -->
	<xsl:include href="<!--GADGET:LANGUAGE-->/language.xsl" />
	<xsl:include href="<!--GADGET:LANGUAGE-->/language_webcomponents.xsl" />
	<!-- Language File Include - End -->
	
	<!-- Gadget Variables File Include - Beginning -->
	<xsl:include href="gadget_variables.xsl" />
	<!-- Gadget Variables File Include - End -->
	
	<xsl:template match="data">
		<xsl:variable name="uniqueid" select="//parameters/parameter[@name='uniqueid']" />
		<xsl:variable name="uniqueidsecurityprincipal" select="//parameters/parameter[@name='uniqueidsecurityprincipal']" />
		<xsl:variable name="relatedsecurityprincipalname" select="//parameters/parameter[@name='relatedsecurityprincipalname']" />
		<xsl:variable name="systemid" select="//parameters/parameter[@name='systemid']" />
		<xsl:variable name="adusername" select="//parameters/parameter[@name='adusername']" />
		<xsl:variable name="header" select="//parameters/parameter[@name='header']" />
		<xsl:variable name="function_to_close" select="//parameters/parameter[@name='function_to_close']" />
		<xsl:variable name="parentid">slider-admin-linkedresource-mailbox-details</xsl:variable>
		<xsl:variable name="modus" select="//parameters/parameter[@name='modus']"/>
		<xsl:variable name="openedslider" select="//parameters/parameter[@name='openedslider']"/>
		
		<xsl:variable name="hasPrint">false</xsl:variable>
		<xsl:variable name="hasExportcsv">true</xsl:variable>
		<xsl:variable name="hasExportpdf">true</xsl:variable>
		<xsl:variable name="mode">dev</xsl:variable>

		<xsl:variable name="temp_openedslider">
			<xsl:choose>
				<xsl:when test="not($openedslider) = 'true'">exchange-slider-details-secondary</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$openedslider" />
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<div  class="dac-slider-border-top">
		</div>
		
		<div class="dac-slider-content-wrapper">
			<div class="dac-slider-content">
			
				<h1>
					<xsl:attribute name="title"><xsl:value-of select="$header"/></xsl:attribute>
					<div class="exchange-slider-headline-icon exchange-slider-headline-icon-mailbox"></div>
					<b>
						<xsl:choose>
						  <xsl:when test="string-length($header) > 24">
							<xsl:value-of select="concat(substring($header, 1, 21), '...')"/>
						  </xsl:when>
						  <xsl:otherwise>
							<xsl:value-of select="$header"/>
						  </xsl:otherwise>
						</xsl:choose>
					</b>
				</h1>
			
			<div class="dac-slider-right-options">
				<inchorus-button>
					<xsl:attribute name="id"><xsl:value-of select="$parentid"/>-button-close</xsl:attribute>
					<xsl:attribute name="type">icon</xsl:attribute>
					<xsl:attribute name="icon">close</xsl:attribute>
					<xsl:attribute name="title"><xsl:value-of select="$inchorus_button_close" /></xsl:attribute>
					<xsl:attribute name="highlighting">low</xsl:attribute>
					<xsl:attribute name="active">true</xsl:attribute>
					<xsl:attribute name="border">true</xsl:attribute>
					<xsl:attribute name="hover">true</xsl:attribute>
					<xsl:attribute name="onclick"><xsl:value-of select="$function_to_close" /></xsl:attribute>
				</inchorus-button>
			<xsl:if test="$hasExportcsv = 'true' or $hasExportpdf = 'true'">				
				<inchorus-button>
					<xsl:attribute name="id"><xsl:value-of select="$parentid"/>-button-export</xsl:attribute>
					<xsl:attribute name="type">icon</xsl:attribute>
					<xsl:attribute name="icon">reports</xsl:attribute>
					<xsl:attribute name="title"><xsl:value-of select="$inchorus_button_reports" /></xsl:attribute>
					<xsl:attribute name="highlighting">low</xsl:attribute>
					<xsl:attribute name="active">true</xsl:attribute>
					<xsl:attribute name="border">true</xsl:attribute>
					<xsl:attribute name="hover">true</xsl:attribute>
					<xsl:attribute name="style">float:right;margin-right:0px;right:45px;</xsl:attribute>
					<xsl:attribute name="onclick">
						inchorus.$('<xsl:value-of select="$parentid" />-tooltip-export').activate();
					</xsl:attribute>
				</inchorus-button>
				<inchorus-tooltip>
					<xsl:attribute name="id"><xsl:value-of select="$parentid" />-tooltip-export</xsl:attribute>
					<xsl:attribute name="position">bottom-left</xsl:attribute>
					<xsl:attribute name="active">false</xsl:attribute>
					<xsl:attribute name="closeonoutsideclick">true</xsl:attribute>
					<xsl:attribute name="hascontentfile">false</xsl:attribute>
					<xsl:attribute name="linkedpointerid"><xsl:value-of select="$parentid" />-button-export</xsl:attribute>
					<xsl:attribute name="linkedpointertype">arrow</xsl:attribute>
					<xsl:attribute name="deactivationcontentmode">remove</xsl:attribute>
					<xsl:attribute name="class">dac-tooltip-reports</xsl:attribute>
					
					<div class="dac-exchange-tooltip-wrapper">
					
						<xsl:if test="$hasExportpdf = 'true'">							
							<div class="dac-exchange-tooltip-reports-row">
								<xsl:attribute name="onClick">
									inchorus.$('<xsl:value-of select="$parentid"/>-export-form').setParameters(
									{
										'uniqueid' : '<xsl:value-of select="$uniqueid"/>',
										'systemid' : '<xsl:value-of select="$systemid"/>',
										'orientation' : 'portrait',
										'exporttype' : 'pdf'
										
									});
									inchorus.$('<xsl:value-of select="$parentid"/>-export-form').submit();
								</xsl:attribute>
								<div class="dac-exchange-reports-pdf" />
								<xsl:value-of select="$inchorus_tooltip_reports_pdf" />
							</div>
						</xsl:if>
						<xsl:if test="$hasExportcsv = 'true'">
								<div class="dac-exchange-tooltip-reports-row-last">
								<xsl:attribute name="onClick">
									inchorus.$('<xsl:value-of select="$parentid"/>-export-form').setParameters(
									{
										'uniqueid' : '<xsl:value-of select="$uniqueid"/>',
										'systemid' : '<xsl:value-of select="$systemid"/>',
										'exporttype' : 'csv'
										
									});
									inchorus.$('<xsl:value-of select="$parentid"/>-export-form').submit();
								</xsl:attribute>
								<div class="dac-exchange-reports-csv" />
								<xsl:value-of select="$inchorus_tooltip_reports_csv" />
							</div>
						</xsl:if>
					</div>
					
				</inchorus-tooltip>
				<inchorus-form>
					<xsl:attribute name="id"><xsl:value-of select="$parentid"/>-export-form</xsl:attribute>
					<xsl:attribute name="submitprefix">inc-</xsl:attribute>
					<xsl:attribute name="responsetype">download</xsl:attribute>
					<xsl:attribute name="hasresponsefile">true</xsl:attribute>
					<xsl:attribute name="command">exportMailboxDetails</xsl:attribute>
				</inchorus-form>
			</xsl:if>
			<xsl:if test="$hasPrint = 'true'">
				<inchorus-button>
					<xsl:attribute name="id"><xsl:value-of select="$parentid"/>-button-print</xsl:attribute>
					<xsl:attribute name="type">icon</xsl:attribute>
					<xsl:attribute name="icon">print</xsl:attribute>
					<xsl:attribute name="title"><xsl:value-of select="$inchorus_button_print" /></xsl:attribute>
					<xsl:attribute name="highlighting">low</xsl:attribute>
					<xsl:attribute name="active">true</xsl:attribute>
					<xsl:attribute name="border">true</xsl:attribute>
					<xsl:attribute name="hover">true</xsl:attribute>
					<xsl:choose>
						<xsl:when test="$hasExportcsv = 'true' or $hasExportpdf = 'true'">
							<xsl:attribute name="style">float:right;margin-right:15px;</xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="style">float:right;margin-right:0px;</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:attribute name="onclick">
						inchorus.$('<xsl:value-of select="$parentid"/>-print').submit();
					</xsl:attribute>
				</inchorus-button>						
				<inchorus-form>
					<xsl:attribute name="id"><xsl:value-of select="$parentid"/>-print</xsl:attribute>
					<xsl:attribute name="submitprefix">inc-</xsl:attribute>
					<xsl:attribute name="responsetype">tab</xsl:attribute>
					<xsl:attribute name="hasresponsefile">true</xsl:attribute>
					<xsl:attribute name="command">exportGroupDetails</xsl:attribute>
					<xsl:attribute name="parameters">[{"uniqueid":"<xsl:value-of select="$uniqueid"/>"}, {"systemid":"<xsl:value-of select="$systemid"/>"}]</xsl:attribute>
				</inchorus-form>
			</xsl:if>
			</div>
			
			<div class="dac-slider-right-content-wrapper">
					<div class="dac-slider-right-content-buttonbar">
						<inchorus-button>
							<xsl:attribute name="id"><xsl:value-of select="$parentid" />-button-mailbox</xsl:attribute>
							<xsl:attribute name="active">true</xsl:attribute>
							<xsl:attribute name="title"><xsl:value-of select="$exchange_button_general" /></xsl:attribute>
							<xsl:attribute name="type">icon</xsl:attribute>
							<xsl:attribute name="icon">menu</xsl:attribute>
							<xsl:attribute name="highlighting">high</xsl:attribute>
							<xsl:attribute name="onclick">
								jQuery('#<xsl:value-of select="$temp_openedslider" />').addClass('dac-slider-right-100percent');
								jQuery('#<xsl:value-of select="$temp_openedslider" />').removeClass('dac-slider-right-60percent');
								jQuery('#<xsl:value-of select="$temp_openedslider" />').removeClass('dac-slider-right-30percent');
								inchorus.$('slider-admin-linkedresource-mailbox-details-history').deactivate();
								inchorus.$('slider-admin-linkedresource-mailbox-details-mailbox').activate();
								inchorus.$('slider-admin-linkedresource-mailbox-details-tabs-content').activate();
								jQuery('#<xsl:value-of select="$parentid" />-button-mailbox').attr('highlighting','high');
								jQuery('#<xsl:value-of select="$parentid" />-button-history').attr('highlighting','low');
							</xsl:attribute>
						</inchorus-button>
						
						<inchorus-button>
							<xsl:attribute name="id"><xsl:value-of select="$parentid" />-button-history</xsl:attribute>
							<xsl:attribute name="active">true</xsl:attribute>
							<xsl:attribute name="title"><xsl:value-of select="$exchange_button_history" /></xsl:attribute>
							<xsl:attribute name="type">icon</xsl:attribute>
							<xsl:attribute name="icon">history</xsl:attribute>
							<xsl:attribute name="highlighting">low</xsl:attribute>
							<xsl:attribute name="onclick">
								jQuery('#<xsl:value-of select="$temp_openedslider" />').addClass('dac-slider-right-30percent');
								jQuery('#<xsl:value-of select="$temp_openedslider" />').removeClass('dac-slider-right-100percent');
								jQuery('#<xsl:value-of select="$temp_openedslider" />').removeClass('dac-slider-right-60percent');
								inchorus.$('slider-admin-linkedresource-mailbox-details-mailbox').deactivate();
								inchorus.$('slider-admin-linkedresource-mailbox-details-history').activate();
								jQuery('#<xsl:value-of select="$parentid" />-button-mailbox').attr('highlighting','low');
								jQuery('#<xsl:value-of select="$parentid" />-button-history').attr('highlighting','high');
							</xsl:attribute>
						</inchorus-button>
					</div>

					<inchorus-content>
				  		<xsl:attribute name="id"><xsl:value-of select="$parentid" />-mailbox</xsl:attribute>
				  		<xsl:attribute name="hascontentfile">true</xsl:attribute>
				  		<xsl:attribute name="active">true</xsl:attribute>
				  		<xsl:attribute name="command">getMailboxDetails</xsl:attribute>
				  		<xsl:attribute name="parameters">[{"uniqueid":"<xsl:value-of select="$uniqueid"/>"},{"uniqueidsecurityprincipal":"<xsl:value-of select="$uniqueidsecurityprincipal" />"},{"systemid":"<xsl:value-of select="$systemid"/>"},{"modus":"<xsl:value-of select="$modus" />"},{"openedslider":"<xsl:value-of select="$temp_openedslider"/>"}]</xsl:attribute>
					</inchorus-content>
					
					<inchorus-content>
				  		<xsl:attribute name="id"><xsl:value-of select="$parentid" />-history</xsl:attribute>
				  		<xsl:attribute name="hascontentfile">true</xsl:attribute>
				  		<xsl:attribute name="active">false</xsl:attribute>
				  		<xsl:attribute name="command">getDefaultData</xsl:attribute>
				  		<xsl:attribute name="parameters">[{"uniqueid":"<xsl:value-of select="$uniqueid"/>"},{"uniqueidsecurityprincipal":"<xsl:value-of select="$uniqueidsecurityprincipal" />"},{"systemid":"<xsl:value-of select="$systemid"/>"},{"openedslider":"<xsl:value-of select="$temp_openedslider"/>"}]</xsl:attribute>
					</inchorus-content>
				</div>
			</div>
			
			<div class="dac-slider-content-placeholder">
				<div class="dac-slider-content-placeholder-line">
				</div>
			</div>
			
			<div class="dac-slider-content-extension">
				<xsl:attribute name="id"><xsl:value-of select="$parentid" />-left</xsl:attribute>
				<inchorus-content>
			  		<xsl:attribute name="id"><xsl:value-of select="$parentid" />-tabs-content</xsl:attribute>
					<inchorus-tabs>
						<xsl:attribute name="id"><xsl:value-of select="$parentid" />-tabs</xsl:attribute>
	    				<xsl:attribute name="activeheaderid"><xsl:value-of select="$parentid" />-tabs-header-1</xsl:attribute>				
	    				<xsl:attribute name="style">margin-top:-32px;</xsl:attribute>
	    				
	    				<inchorus-tab-header-area>
	    					<xsl:attribute name="id"><xsl:value-of select="$parentid" />-tabs-header-area</xsl:attribute>
	      
	      					<inchorus-tab-header>
	      						<xsl:attribute name="id"><xsl:value-of select="$parentid" />-tabs-header-1</xsl:attribute>				
	        					<xsl:attribute name="linkedcontentid"><xsl:value-of select="$parentid" />-tabs-content-1</xsl:attribute>		
	        					<xsl:value-of select="$exchange_effectiv_tab_mailboxpermissions" />
	     			      	</inchorus-tab-header>
	 	  				</inchorus-tab-header-area>
	 	  				
	 	  				<inchorus-tab-content-area>
					    	<xsl:attribute name="id"><xsl:value-of select="$parentid" />-tabs-content-area</xsl:attribute>
					    	
					    	<inchorus-tab-content>
					      		<xsl:attribute name="id"><xsl:value-of select="$parentid" />-tabs-content-1</xsl:attribute>
								<xsl:attribute name="style">padding-top:10px;</xsl:attribute>
							
								<inchorus-content>
							  		<xsl:attribute name="id"><xsl:value-of select="$parentid" />-effective-view</xsl:attribute>
							  		<xsl:attribute name="hascontentfile">true</xsl:attribute>
							  		<xsl:attribute name="alternativecontentfile">exchange-admin-general-effective-tree</xsl:attribute>
							  		<xsl:attribute name="active">true</xsl:attribute>
							  		<xsl:attribute name="parameters">[{"modus":"effectiveview_aduser"},{"uniqueid":"<xsl:value-of select="$uniqueid" />"},{"adusername":"<xsl:value-of select="$adusername" />"}]</xsl:attribute>
							  		<xsl:attribute name="command">getExchangeRelationsForUser</xsl:attribute>
							  		<xsl:attribute name="style">padding:20px;</xsl:attribute>
								</inchorus-content>
								
							</inchorus-tab-content>
						</inchorus-tab-content-area>
					</inchorus-tabs>
				</inchorus-content>
				
				<inchorus-content>
			  		<xsl:attribute name="id"><xsl:value-of select="$parentid" />-history-list-details</xsl:attribute>
			  		<xsl:attribute name="hascontentfile">true</xsl:attribute>
			  		<xsl:attribute name="alternativecontentfile">slider-admin-mailbox-details-history-list-details</xsl:attribute>
			  		<xsl:attribute name="active">false</xsl:attribute>
			  		<xsl:attribute name="command">getHistoryDetailsById</xsl:attribute>
			  		<xsl:attribute name="style">padding:20px;</xsl:attribute>
				</inchorus-content>
			</div>
		</div>
	</xsl:template>
</xsl:stylesheet>