<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<!--
*
*	Date 	    Programmer		 Version		Description
*	~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*	07/30/2014	Sebastian Radau  	1.0.0		Created 
*	12/20/2016	Thomas Gertler  	1.1.0		webcomponents compatiblity 
*												
*	Copyright (c) G+H Systems GmbH, 2014
*	
*	This development kit is proprietary to G+H Systems GmbH.	
*	All rights reserved. For more information visit the website:
*   www.inchorus.de	
*							
*************************************************************************/-->

	<!-- Output Definition - Beginning -->
	<xsl:output method="html" encoding="<!--GADGET:ENCODING-->" />	
	<!-- Output Definition - End -->

	<!-- Language File Include - Beginning -->
	<xsl:include href="<!--GADGET:LANGUAGE-->/language.xsl" />
	<!-- Language File Include - End -->
	
	<!-- Gadget Variables File Include - Beginning -->
	<xsl:include href="gadget_variables.xsl" />
	<!-- Gadget Variables File Include - End -->
	
	<xsl:template match="data">
		<xsl:variable name="parentid">slider-systemdetails-collectors</xsl:variable>
		<xsl:variable name="name" select="//data/parameters/parameter[@name='name']" />
		<xsl:variable name="systemid" select="//data/parameters/parameter[@name='systemid']" />
		<xsl:variable name="systemtype" select="//data/parameters/parameter[@name='systemtype']" />
		<xsl:variable name="integrationpackagestatus" select="//data/parameters/parameter[@name='integrationpackagestatus']" />
		<xsl:variable name="collectorenginestatus" select="//data/parameters/parameter[@name='collectorenginestatus']" />
		<xsl:variable name="state" select="//data/parameters/parameter[@name='state']" />
		<xsl:variable name="grandparentid" select="//data/parameters/parameter[@name='grandparentid']" />
		<xsl:variable name="boxcontentid" select="//data/parameters/parameter[@name='boxcontentid']" />
		<xsl:variable name="count_running" select="count(//data/collectors/collector/state[text() = 'running'])" />
		<xsl:variable name="count_error" select="count(//data/collectors/collector/state[text() = 'error'])" />
		<xsl:variable name="statuscode" select="statuscode" />

		<script>		
			var count_running = '<xsl:value-of select="$count_running" />';
			if (count_running > 0) {
				if(jQuery('#<xsl:value-of select="$parentid" />').length > 0) {
					setTimeout(function(){
						inchorus.$('<xsl:value-of select="$parentid" />').load();
					}, 3000);
				}
			} else {
				var count_error = '<xsl:value-of select="$count_error" />'
				if (count_error > 0) {
					jQuery('#slider-systemdetails-details-status b').html('<xsl:value-of select="$exchange_slider_details_status_error" />');
					jQuery('#slider-systemdetails-details-status b').removeClass('textcolor_yellow');
					jQuery('#slider-systemdetails-details-status b').removeClass('textcolor_green');
					jQuery('#slider-systemdetails-details-status b').removeClass('textcolor_grey');
					jQuery('#slider-systemdetails-details-status b').addClass('textcolor_red');
				} else {
					var refreshlist = jQuery('#<xsl:value-of select="$parentid" />').attr('refreshlist');
					inchorus.$('slider-systemdetails-details').load();
					
					if (refreshlist == 'true') {
						jQuery('#<xsl:value-of select="$parentid" />').removeAttr('refreshlist');
						inchorus.$('system-admin-systems-filter').submit();
						
						if (jQuery('#accounts-portalsetup-admin-system-slider-collectordetails').length) {
							inchorus.$('accounts-portalsetup-admin-system-slider-collectordetails').load();
						}
					}
				}
				if(jQuery('#slider-systemdetails-details-collectall').length > 0) {
					inchorus.$('slider-systemdetails-details-collectall').setStatus('enabled');
					inchorus.$('slider-systemdetails-details-button-editsystem').setStatus('enabled');
					inchorus.$('slider-systemdetails-details-button-deletedata').setStatus('enabled');
					inchorus.$('slider-systemdetails-details-button-deletesystem').setStatus('enabled');				
					inchorus.$('slider-admin-details-system-details').load();
				}
			};
		</script>
		<xsl:if test="$systemid != ''">
			<div>
				<xsl:attribute name="id"><xsl:value-of select="$parentid"/>-response</xsl:attribute>
			</div>
				
			<div>
				<xsl:choose>
					<xsl:when test="$integrationpackagestatus = 'READY'">
						<xsl:attribute name="class">slider-systemdetails-collectors-ready</xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
						<xsl:attribute name="class">slider-systemdetails-collectors</xsl:attribute>
					</xsl:otherwise>
				</xsl:choose>
				
				<xsl:choose>
					<xsl:when test="//data/collectors/collector">
						<xsl:for-each select="//data/collectors/collector">
							<xsl:variable name="collectorid" select="collectorid" />
							<xsl:variable name="collectorname" select="name" />
							<xsl:variable name="connectorname" select="connectorname" />
							<xsl:variable name="position_mod" select="position() mod 2" />
							<xsl:variable name="laststarttime" select="laststarttime" />
							<xsl:variable name="lastendtime" select="lastendtime" />
							<xsl:variable name="nextstarttime" select="nextstarttime" />
							<xsl:variable name="schedule" select="schedule" />
							<xsl:variable name="result" select="result" />
							<xsl:variable name="resultcode" select="resultcode" />
							<xsl:variable name="status" select="status" />
							<xsl:variable name="state" select="state" />
							<xsl:variable name="totalcollectionsteps" select="totalcollectionsteps" />
							<xsl:variable name="currentcollectionstep" select="currentcollectionstep" />
							<xsl:variable name="processpercentage" select="processpercentage" />
							<xsl:variable name="subcollectorcount" select="subcollectorcount" />
							<xsl:variable name="lastruntime" select="lastruntime" />
							<xsl:variable name="lastruntime_seconds" select="lastruntime_seconds" />
							<xsl:variable name="lastruntime_minutes" select="lastruntime_minutes" />
							<xsl:variable name="lastruntime_hours" select="lastruntime_hours" />
							<xsl:variable name="lastruntime_days" select="lastruntime_days" />
							<xsl:variable name="tempprocesspercentage" select="number($currentcollectionstep) * 100 div number($totalcollectionsteps) - 5" />
							<xsl:variable name="prevcollectorid" select="prevcollectorid" />
							<xsl:variable name="position" select="position()" />

							<xsl:choose>
								<xsl:when test="$prevcollectorid != ''">
									<div class="placeholder-subcollector-with-line">
									</div>
								</xsl:when>
								<xsl:otherwise>
									<div class="placeholder-subcollector">
													
									</div>
								</xsl:otherwise>
							</xsl:choose>	
				
				<inchorus-content>
					<xsl:attribute name="id">setup-csv-system-addedsystems-system-collector-<xsl:value-of select="$collectorid"/></xsl:attribute>			
					<xsl:attribute name="style">border:0px;padding:0px;</xsl:attribute>
					<xsl:choose>
						<xsl:when test="$systemtype = 'HR' or $systemtype = 'Application'">
							<xsl:attribute name="class">dac-system-box-collector-withpointer</xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="class">dac-system-box-collector-withoutpointer</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
					<div>
						<xsl:choose>
							<xsl:when test="$state = 'running'">
								<xsl:attribute name="class">dac-system-box-collector box dac-system-box-warning</xsl:attribute>
							</xsl:when>
							<xsl:when test="$lastendtime = 'null' or $lastendtime ='' or $status = 'notconfigured' or $status = 'notscheduled' or $status = 'disabled'">
								<xsl:attribute name="class">dac-system-box-collector box dac-system-box-notread</xsl:attribute>
							</xsl:when>
							<xsl:when test="$result = 'success'">
								<xsl:attribute name="class">dac-system-box-collector box dac-system-box-success</xsl:attribute>
							</xsl:when>
							<xsl:when test="$result = 'error'">
								<xsl:attribute name="class">dac-system-box-collector box dac-system-box-error</xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="class">dac-system-box-collector box dac-system-box-otherwise</xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
						
						<div class="dac-system-box-collector-header">
							<div class="dac-system-box-collector-headline" style="width:calc(100% - 165px);">
								<xsl:value-of select="substring($connectorname, 1, string-length($connectorname) - 9)" /> - <xsl:value-of select="$collectorname" /> 
							</div>
							
							<div style="overflow:hidden; width:auto;max-width:165px;position:relative; float:right;text-align:right;">
								<div style="overflow:hidden; width:auto;">
									<div style="float:left;width:auto; overflow:hidden;margin-right:0px;margin-top:2px;">
										<xsl:choose>
											<xsl:when test="$status= 'notconfigured'">
												<xsl:attribute name="class">dac-system-box-collector-headline-status textcolor_grey</xsl:attribute>
												<xsl:value-of select="$exchange_slider_message_updated_notconfigured" />
											</xsl:when>
											<xsl:when test="$status= 'notscheduled' and $lastruntime != ''">
												<xsl:attribute name="class">dac-system-box-collector-headline-status textcolor_green</xsl:attribute>
												<xsl:value-of select="$exchange_slider_message_updated_success_short"/>
											</xsl:when>
											<xsl:when test="$status= 'notscheduled'">
												<xsl:attribute name="class">dac-system-box-collector-headline-status textcolor_grey</xsl:attribute>
												<xsl:value-of select="$exchange_slider_message_updated_notscheduled" />
											</xsl:when>
											<xsl:when test="$status= 'disabled'">
												<xsl:attribute name="class">dac-system-box-collector-headline-status textcolor_grey</xsl:attribute>
												<xsl:value-of select="$exchange_slider_message_updated_disabled" />
											</xsl:when>
											<xsl:when test="$state = 'running'">
												<xsl:attribute name="class">dac-system-box-collector-headline-status textcolor_yellow</xsl:attribute>
												<xsl:value-of select="$exchange_slider_message_updated_running"/>
											</xsl:when>
											<xsl:when test="$lastendtime = 'null' or $lastendtime =''">
												<xsl:attribute name="class">dac-system-box-collector-headline-status textcolor_grey</xsl:attribute>
												<xsl:value-of select="$exchange_slider_message_updated_warning"/>
											</xsl:when>
											<xsl:when test="$result = 'success'">
												<xsl:attribute name="class">dac-system-box-collector-headline-status textcolor_green</xsl:attribute>
												<xsl:value-of select="$exchange_slider_message_updated_success_short"/>
											</xsl:when>
											<xsl:when test="$result = 'error'">
												<xsl:attribute name="class">dac-system-box-collector-headline-status textcolor_red</xsl:attribute>
												<xsl:value-of select="$exchange_slider_message_updated_error_short"/>
											</xsl:when>
										</xsl:choose>
									</div>
								</div>
							</div>
						</div>
						<div class="dac-system-box-collector-content">
							<xsl:choose>
								<xsl:when test="$state = 'running'">
									<div class="progress">
										<xsl:attribute name="title"><xsl:value-of select="$processpercentage" />%</xsl:attribute>
										<div class="progress-bar">
											<xsl:choose>
												<xsl:when test="$state = 'running'">
													<xsl:attribute name="class">progress-bar dac-system-progress-warning</xsl:attribute>
													<xsl:attribute name="style">width:<xsl:value-of select="$tempprocesspercentage" />%;</xsl:attribute>
												</xsl:when>
												<xsl:when test="$lastendtime = 'null' or $lastendtime =''">
													<xsl:attribute name="class">progress-bar dac-system-progress-notread</xsl:attribute>
													<xsl:attribute name="style">width:<xsl:value-of select="$processpercentage" />%;</xsl:attribute>
												</xsl:when>
												<xsl:when test="$result = 'success'">
													<xsl:attribute name="class">progress-bar dac-system-progress-success</xsl:attribute>
													<xsl:attribute name="style">width:100%;</xsl:attribute>
												</xsl:when>
												<xsl:when test="$result = 'error'">
													<xsl:attribute name="class">progress-bar dac-system-progress-error</xsl:attribute>
													<xsl:attribute name="style">width:<xsl:value-of select="$tempprocesspercentage" />%;</xsl:attribute>
												</xsl:when>
											</xsl:choose>
										</div>
									</div>
								</xsl:when>
								<xsl:when test="$status = 'notconfigured'">
									<div style="color:#888;height: 32px;line-height: 32px;">
										<xsl:value-of select="$exchange_slider_collector_text_notconfigured" />
									</div>
								</xsl:when>

								<xsl:when test="$status = 'disabled'">
									<div style="color:#888;height: 32px;line-height: 32px;">
										<xsl:value-of select="$exchange_slider_collector_text_disabled" />
									</div>
								</xsl:when>
								<xsl:otherwise>
									<div class="dac-system-box-collector-schedule dac-system-box-collector-schedule-<!--GADGET:LANGUAGE-->">
										<div style="width:20px;float:left;margin-right: 10px;">
											<xsl:if test="($schedule != '' and $status = 'scheduled') or ($status = 'notscheduled' and $lastruntime != '')">
												<img style="width: 20px; height: 20px;margin-top:7px;">
													<xsl:choose>
													<xsl:when test="$status = 'notscheduled' and $lastruntime != ''">
														<xsl:attribute name="style">width: 20px; height: 20px;margin-top:7px; opacity: 0.2;</xsl:attribute>
														<xsl:attribute name="title"><xsl:value-of select="$exchange_slider_title_notscheduler" /></xsl:attribute>
													</xsl:when>
													<xsl:otherwise>
														<xsl:attribute name="style">width: 20px; height: 20px;margin-top:7px;</xsl:attribute>
														<xsl:attribute name="title"><xsl:value-of select="$exchange_slider_title_scheduler" />&#160;(<xsl:value-of select="$exchange_slider_title_scheduler_nextstarttime" />&#160;<xsl:value-of select="$nextstarttime" />)</xsl:attribute>
													</xsl:otherwise>
													</xsl:choose>
													<xsl:attribute name="src">../<xsl:value-of select="$gadgetpath" />/inc/img/icons/scheduler.png</xsl:attribute>
												</img>
											</xsl:if>
										</div>
										<div style="float:left;">
											<xsl:choose>
												<xsl:when test="$laststarttime != ''">
													<xsl:value-of select="$exchange_slider_box_lastcollect" /><br/>
													<xsl:choose>
														<xsl:when test="'<!--GADGET:LANGUAGE-->' = 'de'">
															<xsl:value-of select="substring($laststarttime,9,2)"/>.<xsl:value-of select="substring($laststarttime,6,2)"/>.<xsl:value-of select="substring($laststarttime,1,4)"/>&#160;<xsl:value-of select="substring($laststarttime,12,8)"/>
														</xsl:when>
														<xsl:otherwise>
															<xsl:value-of select="substring($laststarttime,1,4)"/>-<xsl:value-of select="substring($laststarttime,6,2)"/>-<xsl:value-of select="substring($laststarttime,9,2)"/>&#160;<xsl:value-of select="substring($laststarttime,12,8)"/>
														</xsl:otherwise>
													</xsl:choose>
													<xsl:choose>
														<xsl:when test="$lastruntime_days &gt; '0'">
															(<xsl:value-of select="$lastruntime_days" />&#160;<xsl:value-of select="$exchange_days" />&#160;<xsl:value-of select="$lastruntime_hours" />&#160;<xsl:value-of select="$exchange_hours" />&#160;<xsl:value-of select="$lastruntime_minutes" />&#160;<xsl:value-of select="$exchange_minutes" />&#160;<xsl:value-of select="$lastruntime_seconds" />&#160;<xsl:value-of select="$exchange_seconds" />)
														</xsl:when>
														<xsl:when test="$lastruntime_hours &gt; '0'">
															(<xsl:value-of select="$lastruntime_hours" />&#160;<xsl:value-of select="$exchange_hours" />&#160;<xsl:value-of select="$lastruntime_minutes" />&#160;<xsl:value-of select="$exchange_minutes" />&#160;<xsl:value-of select="$lastruntime_seconds" />&#160;<xsl:value-of select="$exchange_seconds" />)
														</xsl:when>
														<xsl:when test="$lastruntime_minutes &gt; '0'">
															(<xsl:value-of select="$lastruntime_minutes" />&#160;<xsl:value-of select="$exchange_minutes" />&#160;<xsl:value-of select="$lastruntime_seconds" />&#160;<xsl:value-of select="$exchange_seconds" />)
														</xsl:when>
														<xsl:otherwise>
															(<xsl:value-of select="$lastruntime_seconds" />&#160;<xsl:value-of select="$exchange_seconds" />)
														</xsl:otherwise>
													</xsl:choose>
												</xsl:when>
												<xsl:otherwise>
													<div style="width: 240px;">
														<xsl:value-of select="$exchange_slider_collector_text_notscheduled" />
													</div>
												</xsl:otherwise>
											</xsl:choose>
										</div>
									</div>
									<div  class="dac-system-box-collector-wrapper-button">
										<xsl:if test="$status != 'notconfigured'">
											<inchorus-button>
												<xsl:attribute name="id"><xsl:value-of select="$parentid"/>-button-run-<xsl:value-of select="$collectorid" /></xsl:attribute>
												<xsl:attribute name="type">icontext</xsl:attribute>
												<xsl:attribute name="icon">start</xsl:attribute>
												<xsl:attribute name="text"><xsl:value-of select="$exchange_slider_details_updatedata" /></xsl:attribute>
												<xsl:attribute name="class">box-button</xsl:attribute>
												<xsl:choose>
													<xsl:when test="$integrationpackagestatus = 'READY' and $collectorenginestatus != 'ERROR_CE_UNREACHABLE'">
														<xsl:attribute name="class">dac-system-box-collector-wrapper-button-ready box-button</xsl:attribute>	
											          		<xsl:attribute name="onclick">
											          			jQuery('#slider-systemdetails-lightbox-validation').attr('class','collectall');
																inchorus.$('slider-systemdetails-lightbox-validation').setAlternativecontentfile('slider-systemdetails-lightbox-validation-collectsingle');
																inchorus.$('slider-systemdetails-lightbox-validation').setParameters(
																	{
																		"collectorid":"<xsl:value-of select="$collectorid"/>",
																		"systemname":"<xsl:value-of select="$name"/>"
																	}
																);
																inchorus.$('slider-systemdetails-lightbox-validation').activate();
															</xsl:attribute>	
														</xsl:when>
													<xsl:otherwise>
														<xsl:attribute name="class">dac-system-box-collector-wrapper-button-otherwise  box-button</xsl:attribute>
													</xsl:otherwise>
												</xsl:choose>
											</inchorus-button>
										</xsl:if>
									</div>
								</xsl:otherwise>
							</xsl:choose>
						</div>
					</div>
				</inchorus-content>

								
													
							<!-- 
							<xsl:choose>
								<xsl:when test="$subcollectorcount &gt; '0'">
									<div class="placeholder-subcollector-with-line">
									</div>
								</xsl:when>
								<xsl:otherwise>
									<div class="placeholder-subcollector">
											
									</div>
								</xsl:otherwise>
							</xsl:choose>
							-->
							

						</xsl:for-each>
					</xsl:when>
				</xsl:choose>
			</div>

			<inchorus-form>
				<xsl:attribute name="id"><xsl:value-of select="$parentid"/>-form</xsl:attribute>
				<xsl:attribute name="submitprefix">inc-</xsl:attribute>
				<xsl:attribute name="alternativeresponsefile"><xsl:value-of select="$parentid"/>-response</xsl:attribute>
				<xsl:attribute name="responsetargetid"><xsl:value-of select="$parentid"/>-response</xsl:attribute>
				<xsl:attribute name="hasresponsefile">true</xsl:attribute>
			</inchorus-form>
			
			<script>
				var boxbutton = document.querySelector(".box-button");

				boxbutton.addEventListener("click",stopBubbling);
				
				function stopBubbling(e) {
					e.stopPropagation();
				}
			</script>
			
			<inchorus-lightbox>
				<xsl:attribute name="id"><xsl:value-of select="$parentid" />-lightbox-addcollector</xsl:attribute>
				<xsl:attribute name="active">false</xsl:attribute>
				<xsl:attribute name="hascontentfile">true</xsl:attribute>
				<xsl:attribute name="alternativecontentfile">slider-collectordetails-lightbox-addcollector</xsl:attribute>
				<xsl:attribute name="parameters">[{"systemid":"<xsl:value-of select="$systemid" />"}]</xsl:attribute>
				<xsl:attribute name="command">getDefaultData</xsl:attribute>
			</inchorus-lightbox>
		</xsl:if>
	</xsl:template>
</xsl:stylesheet>