<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<!--
*
*	Date 	    Programmer		 Version		Description
*	~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*	07/30/2014	Sebastian Radau  	1.0.0		Created 
*	12/20/2016	Thomas Gertler  	1.1.0		webcomponents compatiblity 
*												
*	Copyright (c) G+H Systems GmbH, 2014
*	
*	This development kit is proprietary to G+H Systems GmbH.	
*	All rights reserved. For more information visit the website:
*   www.inchorus.de	
*							
*************************************************************************/-->

	<!-- Output Definition - Beginning -->
	<xsl:output method="html" encoding="<!--GADGET:ENCODING-->" />	
	<!-- Output Definition - End -->

	<!-- Language File Include - Beginning -->
	<xsl:include href="<!--GADGET:LANGUAGE-->/language.xsl" />
	<xsl:include href="<!--GADGET:LANGUAGE-->/language_webcomponents.xsl" />
	<!-- Language File Include - End -->
	
	<!-- Gadget Variables File Include - Beginning -->
	<xsl:include href="gadget_variables.xsl" />
	<!-- Gadget Variables File Include - End -->
	
	<xsl:template match="data">
		<xsl:variable name="parentid">slider-systemdetails</xsl:variable>
		<xsl:variable name="systemid" select="//parameters/parameter[@name='systemid']" />
		<xsl:variable name="systemtype" select="//parameters/parameter[@name='systemtype']" />
		<xsl:variable name="systemname" select="//parameters/parameter[@name='systemname']" />
		<xsl:variable name="collectorid" select="//parameters/parameter[@name='collectorid']" />
		<xsl:variable name="integrationpackagestatus" select="//data/integrationpackage/components/connectors/connector/status" />
		<xsl:variable name="collectorenginestatus" select="//data/collectorengines/collectorengine/statusmessage" />
		<xsl:variable name="path" select="//parameters/parameter[@name='path']" />
		<xsl:variable name="header" select="//parameters/parameter[@name='header']" />
		<xsl:variable name="function_to_close" select="//parameters/parameter[@name='function_to_close']" />

		<xsl:variable name="hasPrint">false</xsl:variable>
		<xsl:variable name="hasExportcsv">false</xsl:variable>
		<xsl:variable name="hasExportpdf">false</xsl:variable>
		<xsl:variable name="mode">dev</xsl:variable>

		<div class="dac-slider-border-top">
		</div>

		<div class="dac-slider-content-wrapper">
			<div class="dac-slider-content">
				
				<div style="margin:0px;">
					<h1 class="integrationpackage-slider-header-h1">
					<img class="integrationpackage-slider-header-image">
						<xsl:attribute name="id"><xsl:value-of select="$parentid" />-image</xsl:attribute>
							<xsl:attribute name="src">../../<xsl:value-of select="$gadgetpath" />/inc/img/icons/integrationspackage_icon_28x28.png</xsl:attribute>
						</img>
						<b><xsl:value-of select="$header" /></b>
					</h1>
				</div>

				<div class="dac-slider-right-options">
					<inchorus-button>
						<xsl:attribute name="id"><xsl:value-of select="$parentid"/>-button-close</xsl:attribute>
						<xsl:attribute name="type">icon</xsl:attribute>
						<xsl:attribute name="icon">close</xsl:attribute>
						<xsl:attribute name="title"><xsl:value-of select="$inchorus_button_close" /></xsl:attribute>
						<xsl:attribute name="highlighting">low</xsl:attribute>
						<xsl:attribute name="active">true</xsl:attribute>
						<xsl:attribute name="border">true</xsl:attribute>
						<xsl:attribute name="hover">true</xsl:attribute>
						<xsl:attribute name="onclick">
							if (jQuery('#slider-systemdetails-collectors').attr('refreshlist') != undefined) {
								var refreshlist = jQuery('#slider-systemdetails-collectors').attr('refreshlist');
								if (refreshlist = 'true') {
									jQuery('#slider-systemdetails-collectors').attr('refreshlist','false');
									inchorus.$('system-admin-systems-filter').submit();
								}
							}
							<xsl:value-of select="$function_to_close" />
						</xsl:attribute>
					</inchorus-button>
						
					<xsl:if test="$hasExportcsv = 'true' or $hasExportpdf = 'true'">				
						<inchorus-button>
							<xsl:attribute name="id"><xsl:value-of select="$parentid"/>-button-export</xsl:attribute>
							<xsl:attribute name="type">icon</xsl:attribute>
							<xsl:attribute name="icon">reports</xsl:attribute>
							<xsl:attribute name="title"><xsl:value-of select="$inchorus_button_reports" /></xsl:attribute>
							<xsl:attribute name="highlighting">low</xsl:attribute>
							<xsl:attribute name="active">true</xsl:attribute>
							<xsl:attribute name="border">true</xsl:attribute>
							<xsl:attribute name="hover">true</xsl:attribute>
							<xsl:attribute name="style">float:right;margin-right:0px;</xsl:attribute>
							<xsl:attribute name="onclick">
								inchorus.$('<xsl:value-of select="$parentid" />-tooltip-export').activate();
							</xsl:attribute>
						</inchorus-button>
						<inchorus-tooltip>
							<xsl:attribute name="id"><xsl:value-of select="$parentid" />-tooltip-export</xsl:attribute>
							<xsl:attribute name="position">bottom-left</xsl:attribute>
							<xsl:attribute name="active">false</xsl:attribute>
							<xsl:attribute name="closeonoutsideclick">true</xsl:attribute>
							<xsl:attribute name="hascontentfile">false</xsl:attribute>
							<xsl:attribute name="linkedpointerid"><xsl:value-of select="$parentid" />-button-export</xsl:attribute>
							<xsl:attribute name="linkedpointertype">arrow</xsl:attribute>
							<xsl:attribute name="deactivationcontentmode">remove</xsl:attribute>
							<xsl:attribute name="class">dac-tooltip-reports</xsl:attribute>
							
							<div class="dac-msfileserver-tooltip-wrapper">
		 						<div class="dac-msfileserver-reports-preload-loading"/>							
									<xsl:if test="$hasExportpdf = 'true'">							
										<div class="dac-msfileserver-tooltip-reports-row">
											<xsl:attribute name="onClick">
												inchorus.$('<xsl:value-of select="$parentid"/>-export-form').setParameters(
												{
													'uniqueid' : '<xsl:value-of select="$systemid"/>',
													'mode' : '<xsl:value-of select="$mode"/>',
													'exporttype' : 'pdf'
													
												});
												inchorus.$('<xsl:value-of select="$parentid"/>-export-form').submit();
											</xsl:attribute>
											<div class="dac-msfileserver-reports-pdf" />
											<xsl:value-of select="$inchorus_tooltip_reports_pdf" />
										</div>
									</xsl:if>
									<xsl:if test="$hasExportcsv = 'true'">
										<div class="dac-msfileserver-tooltip-reports-row-last">
										<xsl:attribute name="onClick">
											inchorus.$('<xsl:value-of select="$parentid"/>-export-form').setParameters(
											{
												'uniqueid' : '<xsl:value-of select="$systemid"/>',
												'mode' : '<xsl:value-of select="$mode"/>',
												'exporttype' : 'csv'
												
											});
											inchorus.$('<xsl:value-of select="$parentid"/>-export-form').submit();
										</xsl:attribute>
									<div class="dac-msfileserver-reports-csv" />
										<xsl:value-of select="$inchorus_tooltip_reports_csv" />
									</div>
								</xsl:if>
							</div>			
						</inchorus-tooltip>
						<inchorus-form>
							<xsl:attribute name="id"><xsl:value-of select="$parentid"/>-export-form</xsl:attribute>
							<xsl:attribute name="submitprefix">inc-</xsl:attribute>
							<xsl:attribute name="responsetype">download</xsl:attribute>
							<xsl:attribute name="hasresponsefile">true</xsl:attribute>
							<xsl:attribute name="command">exportPersonDetails</xsl:attribute>
						</inchorus-form>
					</xsl:if>
					<xsl:if test="$hasPrint = 'true'">
						<inchorus-button>
							<xsl:attribute name="id"><xsl:value-of select="$parentid"/>-button-print</xsl:attribute>
							<xsl:attribute name="type">icon</xsl:attribute>
							<xsl:attribute name="icon">print</xsl:attribute>
							<xsl:attribute name="title"><xsl:value-of select="$inchorus_button_print" /></xsl:attribute>
							<xsl:attribute name="highlighting">low</xsl:attribute>
							<xsl:attribute name="active">true</xsl:attribute>
							<xsl:attribute name="border">true</xsl:attribute>
							<xsl:attribute name="hover">true</xsl:attribute>
							<xsl:choose>
								<xsl:when test="$hasExportcsv = 'true' or $hasExportpdf = 'true'">
									<xsl:attribute name="style">float:right;margin-right:15px;</xsl:attribute>
								</xsl:when>
								<xsl:otherwise>
									<xsl:attribute name="style">float:right;margin-right:0px;</xsl:attribute>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:attribute name="onclick">
								inchorus.$('<xsl:value-of select="$parentid"/>-print').submit();
							</xsl:attribute>
						</inchorus-button>						
						<inchorus-form>
							<xsl:attribute name="id"><xsl:value-of select="$parentid"/>-print</xsl:attribute>
							<xsl:attribute name="submitprefix">inc-</xsl:attribute>
							<xsl:attribute name="responsetype">tab</xsl:attribute>
							<xsl:attribute name="hasresponsefile">true</xsl:attribute>
							<xsl:attribute name="parameters">[{"uniqueid":"<xsl:value-of select="$systemid"/>"}, {"mode":"<xsl:value-of select="$mode"/>"}]</xsl:attribute>
							<xsl:attribute name="command">getPolicyPrintData</xsl:attribute>
						</inchorus-form>
					</xsl:if>
				</div>

				<div style="height:calc(100% - 40px);">
					<div style="width: 100%;overflow:hidden; height:auto;margin-bottom: 20px;">
						<inchorus-button>
							<xsl:attribute name="id"><xsl:value-of select="$parentid" />-button-details</xsl:attribute>
							<xsl:attribute name="active">true</xsl:attribute>
							<xsl:attribute name="type">icon</xsl:attribute>
							<xsl:attribute name="icon">menu</xsl:attribute>
							<xsl:attribute name="highlighting">high</xsl:attribute>
							<xsl:attribute name="onclick">
								jQuery('#system-slider-details').removeClass('system-slider-details-60percent');
								jQuery('#system-slider-details').removeClass('system-slider-details-90percent');
								jQuery('#slider-systemdetails-extension').removeClass('accounts-slider-extenstion-doublewidth');
								inchorus.$('slider-admin-details-folder-history').deactivate();
								inchorus.$('slider-admin-details-folder-details').activate();
								jQuery('#<xsl:value-of select="$parentid" />-button-details').attr('highlighting','high');
								jQuery('#<xsl:value-of select="$parentid" />-button-history').attr('highlighting','low');
							</xsl:attribute>
						</inchorus-button>		
					</div>
					 
					<inchorus-content>
						<xsl:attribute name="id"><xsl:value-of select="$parentid" />-details</xsl:attribute>
						<xsl:attribute name="hascontentfile">true</xsl:attribute>
						<xsl:attribute name="active">true</xsl:attribute>
						<xsl:attribute name="parameters">[{"systemid":"<xsl:value-of select="$systemid"/>"},{"systemtype":"<xsl:value-of select="$systemtype" />"},{"integrationpackagestatus":"<xsl:value-of select="$integrationpackagestatus" />"},{"collectorenginestatus":"<xsl:value-of select="$collectorenginestatus" />"}]</xsl:attribute>
						<xsl:attribute name="command">getSystem</xsl:attribute>
						<div style="height:212px;"></div>
					</inchorus-content>
					
					<div style="height:48px;"></div>
					
						<div style="border: 0px solid #fff;">
							<xsl:attribute name="id"><xsl:value-of select="$parentid" />-div-scollable</xsl:attribute>
							<xsl:attribute name="class">big</xsl:attribute>
						<inchorus-akkordeon>
							<xsl:attribute name="id"><xsl:value-of select="$parentid" />-akkordeon-collectors</xsl:attribute>
							<xsl:attribute name="text">Collectors</xsl:attribute>
							<xsl:attribute name="hascontentfile">false</xsl:attribute>
							<xsl:attribute name="type">first</xsl:attribute>
							<xsl:attribute name="open">true</xsl:attribute>

							<inchorus-content>
								<xsl:attribute name="id"><xsl:value-of select="$parentid" />-collectors</xsl:attribute>
								<xsl:attribute name="hascontentfile">true</xsl:attribute>
								<xsl:attribute name="parameters">[{"name":"<xsl:value-of select="$header" />"},{"systemid":"<xsl:value-of select="$systemid" />"},{"systemtype":"<xsl:value-of select="$systemtype" />"},{"integrationpackagestatus":"<xsl:value-of select="$integrationpackagestatus" />"},{"collectorenginestatus":"<xsl:value-of select="$collectorenginestatus" />"}]</xsl:attribute>
								<xsl:attribute name="command">getCollectors</xsl:attribute>
								<xsl:attribute name="style">border: 0px solid #fff;</xsl:attribute>
							</inchorus-content>

						</inchorus-akkordeon>
					</div>
					
				</div>
			</div>
			
			<div class="dac-slider-content-placeholder">
				<div class="dac-slider-content-placeholder-line" style="border-left:1px solid silver; height:calc(100% - 100px);">
				</div>
			</div>
			
			<div class="dac-slider-content-extension"> 
				<xsl:attribute name="id"><xsl:value-of select="$parentid" />-extension</xsl:attribute>	
 	
				<inchorus-content>
					<xsl:attribute name="id"><xsl:value-of select="$parentid" />-collector-details</xsl:attribute>
					<xsl:attribute name="active">false</xsl:attribute>
					<xsl:attribute name="alternativecontentfile">slider-details-content</xsl:attribute>
					<xsl:attribute name="hascontentfile">true</xsl:attribute>
					<xsl:attribute name="activationcontentmode">always</xsl:attribute>
					<xsl:attribute name="parameters">[{"objecttype":"collectordetails"},{"collectorid":"<xsl:value-of select="$collectorid" />"}]</xsl:attribute>
					<xsl:attribute name="command">getDefaultData</xsl:attribute>					
				</inchorus-content>
			</div>
			
		</div>

		<inchorus-lightbox>
			<xsl:attribute name="id"><xsl:value-of select="$parentid" />-lightbox-editsystem</xsl:attribute>
			<xsl:attribute name="active">false</xsl:attribute>
			<xsl:attribute name="hascontentfile">true</xsl:attribute>
			<xsl:attribute name="alternativecontentfile">exchange-portalsetup-admin-systems-lightbox-editsystem</xsl:attribute>
		</inchorus-lightbox>
		
		<inchorus-lightbox>
			<xsl:attribute name="id"><xsl:value-of select="$parentid" />-lightbox-export</xsl:attribute>
			<xsl:attribute name="active">false</xsl:attribute>
			<xsl:attribute name="hascontentfile">true</xsl:attribute>
		</inchorus-lightbox>
		
		<inchorus-lightbox>
			<xsl:attribute name="id"><xsl:value-of select="$parentid" />-lightbox-validation</xsl:attribute>
			<xsl:attribute name="active">false</xsl:attribute>
			<xsl:attribute name="hascontentfile">true</xsl:attribute>
		</inchorus-lightbox>
	</xsl:template>
</xsl:stylesheet>